@@ -10,29 +10,28 @@ import publication
 
 from .._jsii import *
 
-from .. import Stack as _Stack_05f4505a, Construct as _Construct_f50a3f53
+from .. import Construct as _Construct_f50a3f53, Stack as _Stack_05f4505a
 from ..aws_cloudformation import (
-    CloudFormationCapabilities as _CloudFormationCapabilities_979dd343,
+    CloudFormationCapabilities as _CloudFormationCapabilities_979dd343
 )
 from ..aws_codepipeline import (
-    Artifact as _Artifact_af6d98e9,
-    ActionConfig as _ActionConfig_c379766c,
-    IStage as _IStage_b7c853a7,
     ActionBindOptions as _ActionBindOptions_530c352f,
+    ActionConfig as _ActionConfig_c379766c,
     ActionProperties as _ActionProperties_8f5d7a9d,
+    Artifact as _Artifact_af6d98e9,
     IAction as _IAction_369e77ae,
+    IStage as _IStage_b7c853a7,
 )
 from ..aws_events import (
-    Rule as _Rule_c38e0b39,
-    IRuleTarget as _IRuleTarget_41800a77,
-    RuleProps as _RuleProps_d60f0abf,
-    IEventBus as _IEventBus_ed4f1700,
     EventPattern as _EventPattern_8aa7b781,
+    IEventBus as _IEventBus_ed4f1700,
+    IRuleTarget as _IRuleTarget_41800a77,
+    Rule as _Rule_c38e0b39,
+    RuleProps as _RuleProps_d60f0abf,
     Schedule as _Schedule_11a70620,
 )
 from ..aws_iam import (
-    IRole as _IRole_e69bbae4,
-    PolicyStatement as _PolicyStatement_f75dc775,
+    IRole as _IRole_e69bbae4, PolicyStatement as _PolicyStatement_f75dc775
 )
 from ..aws_s3 import IBucket as _IBucket_25bad983
 
@@ -60,9 +59,7 @@ class PipelineDeployStackAction(
         admin_permissions: bool,
         input: _Artifact_af6d98e9,
         stack: _Stack_05f4505a,
-        capabilities: typing.Optional[
-            typing.List[_CloudFormationCapabilities_979dd343]
-        ] = None,
+        capabilities: typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]] = None,
         change_set_name: typing.Optional[str] = None,
         create_change_set_action_name: typing.Optional[str] = None,
         create_change_set_run_order: typing.Optional[jsii.Number] = None,
@@ -223,9 +220,7 @@ class PipelineDeployStackActionProps:
         admin_permissions: bool,
         input: _Artifact_af6d98e9,
         stack: _Stack_05f4505a,
-        capabilities: typing.Optional[
-            typing.List[_CloudFormationCapabilities_979dd343]
-        ] = None,
+        capabilities: typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]] = None,
         change_set_name: typing.Optional[str] = None,
         create_change_set_action_name: typing.Optional[str] = None,
         create_change_set_run_order: typing.Optional[jsii.Number] = None,
@@ -258,15 +253,11 @@ class PipelineDeployStackActionProps:
         if change_set_name is not None:
             self._values["change_set_name"] = change_set_name
         if create_change_set_action_name is not None:
-            self._values[
-                "create_change_set_action_name"
-            ] = create_change_set_action_name
+            self._values["create_change_set_action_name"] = create_change_set_action_name
         if create_change_set_run_order is not None:
             self._values["create_change_set_run_order"] = create_change_set_run_order
         if execute_change_set_action_name is not None:
-            self._values[
-                "execute_change_set_action_name"
-            ] = execute_change_set_action_name
+            self._values["execute_change_set_action_name"] = execute_change_set_action_name
         if execute_change_set_run_order is not None:
             self._values["execute_change_set_run_order"] = execute_change_set_run_order
         if role is not None:
