@@ -13,10 +13,10 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -46,29 +46,14 @@ class CfnBroker(
         engine_version: str,
         host_instance_type: str,
         publicly_accessible: typing.Union[bool, _IResolvable_9ceae33e],
-        users: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["UserProperty", _IResolvable_9ceae33e]],
-        ],
+        users: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["UserProperty", _IResolvable_9ceae33e]]],
         authentication_strategy: typing.Optional[str] = None,
-        configuration: typing.Optional[
-            typing.Union["ConfigurationIdProperty", _IResolvable_9ceae33e]
-        ] = None,
-        encryption_options: typing.Optional[
-            typing.Union["EncryptionOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
-        ldap_metadata: typing.Optional[
-            typing.Union["LdapMetadataProperty", _IResolvable_9ceae33e]
-        ] = None,
-        ldap_server_metadata: typing.Optional[
-            typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]
-        ] = None,
-        logs: typing.Optional[
-            typing.Union["LogListProperty", _IResolvable_9ceae33e]
-        ] = None,
-        maintenance_window_start_time: typing.Optional[
-            typing.Union["MaintenanceWindowProperty", _IResolvable_9ceae33e]
-        ] = None,
+        configuration: typing.Optional[typing.Union["ConfigurationIdProperty", _IResolvable_9ceae33e]] = None,
+        encryption_options: typing.Optional[typing.Union["EncryptionOptionsProperty", _IResolvable_9ceae33e]] = None,
+        ldap_metadata: typing.Optional[typing.Union["LdapMetadataProperty", _IResolvable_9ceae33e]] = None,
+        ldap_server_metadata: typing.Optional[typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]] = None,
+        logs: typing.Optional[typing.Union["LogListProperty", _IResolvable_9ceae33e]] = None,
+        maintenance_window_start_time: typing.Optional[typing.Union["MaintenanceWindowProperty", _IResolvable_9ceae33e]] = None,
         security_groups: typing.Optional[typing.List[str]] = None,
         storage_type: typing.Optional[str] = None,
         subnet_ids: typing.Optional[typing.List[str]] = None,
@@ -350,10 +335,7 @@ class CfnBroker(
     @jsii.member(jsii_name="users")
     def users(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["UserProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["UserProperty", _IResolvable_9ceae33e]]]:
         """``AWS::AmazonMQ::Broker.Users``.
 
         see
@@ -364,10 +346,7 @@ class CfnBroker(
     @users.setter
     def users(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["UserProperty", _IResolvable_9ceae33e]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["UserProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "users", value)
 
@@ -389,9 +368,7 @@ class CfnBroker(
     @jsii.member(jsii_name="configuration")
     def configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["ConfigurationIdProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["ConfigurationIdProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.Configuration``.
 
         see
@@ -402,9 +379,7 @@ class CfnBroker(
     @configuration.setter
     def configuration(
         self,
-        value: typing.Optional[
-            typing.Union["ConfigurationIdProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["ConfigurationIdProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "configuration", value)
 
@@ -412,9 +387,7 @@ class CfnBroker(
     @jsii.member(jsii_name="encryptionOptions")
     def encryption_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["EncryptionOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["EncryptionOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.EncryptionOptions``.
 
         see
@@ -425,9 +398,7 @@ class CfnBroker(
     @encryption_options.setter
     def encryption_options(
         self,
-        value: typing.Optional[
-            typing.Union["EncryptionOptionsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["EncryptionOptionsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "encryptionOptions", value)
 
@@ -446,9 +417,7 @@ class CfnBroker(
     @ldap_metadata.setter
     def ldap_metadata(
         self,
-        value: typing.Optional[
-            typing.Union["LdapMetadataProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["LdapMetadataProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "ldapMetadata", value)
 
@@ -456,9 +425,7 @@ class CfnBroker(
     @jsii.member(jsii_name="ldapServerMetadata")
     def ldap_server_metadata(
         self,
-    ) -> typing.Optional[
-        typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.LdapServerMetadata``.
 
         see
@@ -469,9 +436,7 @@ class CfnBroker(
     @ldap_server_metadata.setter
     def ldap_server_metadata(
         self,
-        value: typing.Optional[
-            typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "ldapServerMetadata", value)
 
@@ -498,9 +463,7 @@ class CfnBroker(
     @jsii.member(jsii_name="maintenanceWindowStartTime")
     def maintenance_window_start_time(
         self,
-    ) -> typing.Optional[
-        typing.Union["MaintenanceWindowProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["MaintenanceWindowProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.MaintenanceWindowStartTime``.
 
         see
@@ -511,9 +474,7 @@ class CfnBroker(
     @maintenance_window_start_time.setter
     def maintenance_window_start_time(
         self,
-        value: typing.Optional[
-            typing.Union["MaintenanceWindowProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["MaintenanceWindowProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "maintenanceWindowStartTime", value)
 
@@ -721,19 +682,8 @@ class CfnBroker(
         def __init__(
             self,
             *,
-            server_metadata: typing.Union[
-                "CfnBroker.ServerMetadataProperty", _IResolvable_9ceae33e
-            ],
-            inter_broker_creds: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[
-                        typing.Union[
-                            "CfnBroker.InterBrokerCredProperty", _IResolvable_9ceae33e
-                        ]
-                    ],
-                ]
-            ] = None,
+            server_metadata: typing.Union["CfnBroker.ServerMetadataProperty", _IResolvable_9ceae33e],
+            inter_broker_creds: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBroker.InterBrokerCredProperty", _IResolvable_9ceae33e]]]] = None,
         ) -> None:
             """
             :param server_metadata: ``CfnBroker.LdapMetadataProperty.ServerMetadata``.
@@ -762,16 +712,7 @@ class CfnBroker(
         @builtins.property
         def inter_broker_creds(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnBroker.InterBrokerCredProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBroker.InterBrokerCredProperty", _IResolvable_9ceae33e]]]]:
             """``CfnBroker.LdapMetadataProperty.InterBrokerCreds``.
 
             see
@@ -819,13 +760,9 @@ class CfnBroker(
             user_base: str,
             user_search_matching: str,
             role_name: typing.Optional[str] = None,
-            role_search_subtree: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            role_search_subtree: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             user_role_name: typing.Optional[str] = None,
-            user_search_subtree: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            user_search_subtree: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param hosts: ``CfnBroker.LdapServerMetadataProperty.Hosts``.
@@ -1123,13 +1060,9 @@ class CfnBroker(
             user_base: str,
             user_search_matching: str,
             role_name: typing.Optional[str] = None,
-            role_search_subtree: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            role_search_subtree: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             user_role_name: typing.Optional[str] = None,
-            user_search_subtree: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            user_search_subtree: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param hosts: ``CfnBroker.ServerMetadataProperty.Hosts``.
@@ -1343,9 +1276,7 @@ class CfnBroker(
             *,
             password: str,
             username: str,
-            console_access: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            console_access: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             groups: typing.Optional[typing.List[str]] = None,
         ) -> None:
             """
@@ -1452,29 +1383,14 @@ class CfnBrokerProps:
         engine_version: str,
         host_instance_type: str,
         publicly_accessible: typing.Union[bool, _IResolvable_9ceae33e],
-        users: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["CfnBroker.UserProperty", _IResolvable_9ceae33e]],
-        ],
+        users: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBroker.UserProperty", _IResolvable_9ceae33e]]],
         authentication_strategy: typing.Optional[str] = None,
-        configuration: typing.Optional[
-            typing.Union["CfnBroker.ConfigurationIdProperty", _IResolvable_9ceae33e]
-        ] = None,
-        encryption_options: typing.Optional[
-            typing.Union["CfnBroker.EncryptionOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
-        ldap_metadata: typing.Optional[
-            typing.Union["CfnBroker.LdapMetadataProperty", _IResolvable_9ceae33e]
-        ] = None,
-        ldap_server_metadata: typing.Optional[
-            typing.Union["CfnBroker.LdapServerMetadataProperty", _IResolvable_9ceae33e]
-        ] = None,
-        logs: typing.Optional[
-            typing.Union["CfnBroker.LogListProperty", _IResolvable_9ceae33e]
-        ] = None,
-        maintenance_window_start_time: typing.Optional[
-            typing.Union["CfnBroker.MaintenanceWindowProperty", _IResolvable_9ceae33e]
-        ] = None,
+        configuration: typing.Optional[typing.Union["CfnBroker.ConfigurationIdProperty", _IResolvable_9ceae33e]] = None,
+        encryption_options: typing.Optional[typing.Union["CfnBroker.EncryptionOptionsProperty", _IResolvable_9ceae33e]] = None,
+        ldap_metadata: typing.Optional[typing.Union["CfnBroker.LdapMetadataProperty", _IResolvable_9ceae33e]] = None,
+        ldap_server_metadata: typing.Optional[typing.Union["CfnBroker.LdapServerMetadataProperty", _IResolvable_9ceae33e]] = None,
+        logs: typing.Optional[typing.Union["CfnBroker.LogListProperty", _IResolvable_9ceae33e]] = None,
+        maintenance_window_start_time: typing.Optional[typing.Union["CfnBroker.MaintenanceWindowProperty", _IResolvable_9ceae33e]] = None,
         security_groups: typing.Optional[typing.List[str]] = None,
         storage_type: typing.Optional[str] = None,
         subnet_ids: typing.Optional[typing.List[str]] = None,
@@ -1528,9 +1444,7 @@ class CfnBrokerProps:
         if logs is not None:
             self._values["logs"] = logs
         if maintenance_window_start_time is not None:
-            self._values[
-                "maintenance_window_start_time"
-            ] = maintenance_window_start_time
+            self._values["maintenance_window_start_time"] = maintenance_window_start_time
         if security_groups is not None:
             self._values["security_groups"] = security_groups
         if storage_type is not None:
@@ -1606,10 +1520,7 @@ class CfnBrokerProps:
     @builtins.property
     def users(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["CfnBroker.UserProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBroker.UserProperty", _IResolvable_9ceae33e]]]:
         """``AWS::AmazonMQ::Broker.Users``.
 
         see
@@ -1629,9 +1540,7 @@ class CfnBrokerProps:
     @builtins.property
     def configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnBroker.ConfigurationIdProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnBroker.ConfigurationIdProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.Configuration``.
 
         see
@@ -1642,9 +1551,7 @@ class CfnBrokerProps:
     @builtins.property
     def encryption_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnBroker.EncryptionOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnBroker.EncryptionOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.EncryptionOptions``.
 
         see
@@ -1655,9 +1562,7 @@ class CfnBrokerProps:
     @builtins.property
     def ldap_metadata(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnBroker.LdapMetadataProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnBroker.LdapMetadataProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.LdapMetadata``.
 
         see
@@ -1668,9 +1573,7 @@ class CfnBrokerProps:
     @builtins.property
     def ldap_server_metadata(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnBroker.LdapServerMetadataProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnBroker.LdapServerMetadataProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.LdapServerMetadata``.
 
         see
@@ -1681,9 +1584,7 @@ class CfnBrokerProps:
     @builtins.property
     def logs(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnBroker.LogListProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnBroker.LogListProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.Logs``.
 
         see
@@ -1694,9 +1595,7 @@ class CfnBrokerProps:
     @builtins.property
     def maintenance_window_start_time(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnBroker.MaintenanceWindowProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnBroker.MaintenanceWindowProperty", _IResolvable_9ceae33e]]:
         """``AWS::AmazonMQ::Broker.MaintenanceWindowStartTime``.
 
         see
@@ -2144,9 +2043,7 @@ class CfnConfigurationAssociationProps:
         self,
         *,
         broker: str,
-        configuration: typing.Union[
-            "CfnConfigurationAssociation.ConfigurationIdProperty", _IResolvable_9ceae33e
-        ],
+        configuration: typing.Union["CfnConfigurationAssociation.ConfigurationIdProperty", _IResolvable_9ceae33e],
     ) -> None:
         """Properties for defining a ``AWS::AmazonMQ::ConfigurationAssociation``.
 
@@ -2173,9 +2070,7 @@ class CfnConfigurationAssociationProps:
     @builtins.property
     def configuration(
         self,
-    ) -> typing.Union[
-        "CfnConfigurationAssociation.ConfigurationIdProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnConfigurationAssociation.ConfigurationIdProperty", _IResolvable_9ceae33e]:
         """``AWS::AmazonMQ::ConfigurationAssociation.Configuration``.
 
         see
