@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -276,12 +276,7 @@ class CfnConfigurationProfile(
         description: typing.Optional[str] = None,
         retrieval_role_arn: typing.Optional[str] = None,
         tags: typing.Optional[typing.List["TagsProperty"]] = None,
-        validators: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ValidatorsProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        validators: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ValidatorsProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::AppConfig::ConfigurationProfile``.
 
@@ -426,12 +421,7 @@ class CfnConfigurationProfile(
     @jsii.member(jsii_name="validators")
     def validators(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ValidatorsProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ValidatorsProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::AppConfig::ConfigurationProfile.Validators``.
 
         see
@@ -442,12 +432,7 @@ class CfnConfigurationProfile(
     @validators.setter
     def validators(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ValidatorsProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ValidatorsProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "validators", value)
 
@@ -582,20 +567,8 @@ class CfnConfigurationProfileProps:
         name: str,
         description: typing.Optional[str] = None,
         retrieval_role_arn: typing.Optional[str] = None,
-        tags: typing.Optional[
-            typing.List["CfnConfigurationProfile.TagsProperty"]
-        ] = None,
-        validators: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnConfigurationProfile.ValidatorsProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        tags: typing.Optional[typing.List["CfnConfigurationProfile.TagsProperty"]] = None,
+        validators: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnConfigurationProfile.ValidatorsProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::AppConfig::ConfigurationProfile``.
 
@@ -683,16 +656,7 @@ class CfnConfigurationProfileProps:
     @builtins.property
     def validators(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnConfigurationProfile.ValidatorsProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnConfigurationProfile.ValidatorsProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::AppConfig::ConfigurationProfile.Validators``.
 
         see
@@ -1488,12 +1452,7 @@ class CfnEnvironment(
         application_id: str,
         name: str,
         description: typing.Optional[str] = None,
-        monitors: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["MonitorsProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        monitors: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["MonitorsProperty", _IResolvable_9ceae33e]]]] = None,
         tags: typing.Optional[typing.List["TagsProperty"]] = None,
     ) -> None:
         """Create a new ``AWS::AppConfig::Environment``.
@@ -1593,12 +1552,7 @@ class CfnEnvironment(
     @jsii.member(jsii_name="monitors")
     def monitors(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["MonitorsProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["MonitorsProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::AppConfig::Environment.Monitors``.
 
         see
@@ -1609,12 +1563,7 @@ class CfnEnvironment(
     @monitors.setter
     def monitors(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["MonitorsProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["MonitorsProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "monitors", value)
 
@@ -1759,16 +1708,7 @@ class CfnEnvironmentProps:
         application_id: str,
         name: str,
         description: typing.Optional[str] = None,
-        monitors: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnEnvironment.MonitorsProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        monitors: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironment.MonitorsProperty", _IResolvable_9ceae33e]]]] = None,
         tags: typing.Optional[typing.List["CfnEnvironment.TagsProperty"]] = None,
     ) -> None:
         """Properties for defining a ``AWS::AppConfig::Environment``.
@@ -1823,14 +1763,7 @@ class CfnEnvironmentProps:
     @builtins.property
     def monitors(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnEnvironment.MonitorsProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironment.MonitorsProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::AppConfig::Environment.Monitors``.
 
         see
