@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -38,15 +38,8 @@ class CfnScalingPlan(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        application_source: typing.Union[
-            "ApplicationSourceProperty", _IResolvable_9ceae33e
-        ],
-        scaling_instructions: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]
-            ],
-        ],
+        application_source: typing.Union["ApplicationSourceProperty", _IResolvable_9ceae33e],
+        scaling_instructions: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         """Create a new ``AWS::AutoScalingPlans::ScalingPlan``.
 
@@ -133,10 +126,7 @@ class CfnScalingPlan(
     @jsii.member(jsii_name="scalingInstructions")
     def scaling_instructions(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]]]:
         """``AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions``.
 
         see
@@ -147,12 +137,7 @@ class CfnScalingPlan(
     @scaling_instructions.setter
     def scaling_instructions(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]
-            ],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ScalingInstructionProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "scalingInstructions", value)
 
@@ -169,16 +154,7 @@ class CfnScalingPlan(
             self,
             *,
             cloud_formation_stack_arn: typing.Optional[str] = None,
-            tag_filters: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[
-                        typing.Union[
-                            "CfnScalingPlan.TagFilterProperty", _IResolvable_9ceae33e
-                        ]
-                    ],
-                ]
-            ] = None,
+            tag_filters: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.TagFilterProperty", _IResolvable_9ceae33e]]]] = None,
         ) -> None:
             """
             :param cloud_formation_stack_arn: ``CfnScalingPlan.ApplicationSourceProperty.CloudFormationStackARN``.
@@ -205,16 +181,7 @@ class CfnScalingPlan(
         @builtins.property
         def tag_filters(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnScalingPlan.TagFilterProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.TagFilterProperty", _IResolvable_9ceae33e]]]]:
             """``CfnScalingPlan.ApplicationSourceProperty.TagFilters``.
 
             see
@@ -251,17 +218,7 @@ class CfnScalingPlan(
             metric_name: str,
             namespace: str,
             statistic: str,
-            dimensions: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[
-                        typing.Union[
-                            "CfnScalingPlan.MetricDimensionProperty",
-                            _IResolvable_9ceae33e,
-                        ]
-                    ],
-                ]
-            ] = None,
+            dimensions: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.MetricDimensionProperty", _IResolvable_9ceae33e]]]] = None,
             unit: typing.Optional[str] = None,
         ) -> None:
             """
@@ -314,16 +271,7 @@ class CfnScalingPlan(
         @builtins.property
         def dimensions(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnScalingPlan.MetricDimensionProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.MetricDimensionProperty", _IResolvable_9ceae33e]]]]:
             """``CfnScalingPlan.CustomizedLoadMetricSpecificationProperty.Dimensions``.
 
             see
@@ -369,17 +317,7 @@ class CfnScalingPlan(
             metric_name: str,
             namespace: str,
             statistic: str,
-            dimensions: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[
-                        typing.Union[
-                            "CfnScalingPlan.MetricDimensionProperty",
-                            _IResolvable_9ceae33e,
-                        ]
-                    ],
-                ]
-            ] = None,
+            dimensions: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.MetricDimensionProperty", _IResolvable_9ceae33e]]]] = None,
             unit: typing.Optional[str] = None,
         ) -> None:
             """
@@ -432,16 +370,7 @@ class CfnScalingPlan(
         @builtins.property
         def dimensions(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnScalingPlan.MetricDimensionProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.MetricDimensionProperty", _IResolvable_9ceae33e]]]]:
             """``CfnScalingPlan.CustomizedScalingMetricSpecificationProperty.Dimensions``.
 
             see
@@ -660,30 +589,10 @@ class CfnScalingPlan(
             resource_id: str,
             scalable_dimension: str,
             service_namespace: str,
-            target_tracking_configurations: typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnScalingPlan.TargetTrackingConfigurationProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ],
-            customized_load_metric_specification: typing.Optional[
-                typing.Union[
-                    "CfnScalingPlan.CustomizedLoadMetricSpecificationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
-            disable_dynamic_scaling: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            predefined_load_metric_specification: typing.Optional[
-                typing.Union[
-                    "CfnScalingPlan.PredefinedLoadMetricSpecificationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            target_tracking_configurations: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.TargetTrackingConfigurationProperty", _IResolvable_9ceae33e]]],
+            customized_load_metric_specification: typing.Optional[typing.Union["CfnScalingPlan.CustomizedLoadMetricSpecificationProperty", _IResolvable_9ceae33e]] = None,
+            disable_dynamic_scaling: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            predefined_load_metric_specification: typing.Optional[typing.Union["CfnScalingPlan.PredefinedLoadMetricSpecificationProperty", _IResolvable_9ceae33e]] = None,
             predictive_scaling_max_capacity_behavior: typing.Optional[str] = None,
             predictive_scaling_max_capacity_buffer: typing.Optional[jsii.Number] = None,
             predictive_scaling_mode: typing.Optional[str] = None,
@@ -718,33 +627,21 @@ class CfnScalingPlan(
                 "target_tracking_configurations": target_tracking_configurations,
             }
             if customized_load_metric_specification is not None:
-                self._values[
-                    "customized_load_metric_specification"
-                ] = customized_load_metric_specification
+                self._values["customized_load_metric_specification"] = customized_load_metric_specification
             if disable_dynamic_scaling is not None:
                 self._values["disable_dynamic_scaling"] = disable_dynamic_scaling
             if predefined_load_metric_specification is not None:
-                self._values[
-                    "predefined_load_metric_specification"
-                ] = predefined_load_metric_specification
+                self._values["predefined_load_metric_specification"] = predefined_load_metric_specification
             if predictive_scaling_max_capacity_behavior is not None:
-                self._values[
-                    "predictive_scaling_max_capacity_behavior"
-                ] = predictive_scaling_max_capacity_behavior
+                self._values["predictive_scaling_max_capacity_behavior"] = predictive_scaling_max_capacity_behavior
             if predictive_scaling_max_capacity_buffer is not None:
-                self._values[
-                    "predictive_scaling_max_capacity_buffer"
-                ] = predictive_scaling_max_capacity_buffer
+                self._values["predictive_scaling_max_capacity_buffer"] = predictive_scaling_max_capacity_buffer
             if predictive_scaling_mode is not None:
                 self._values["predictive_scaling_mode"] = predictive_scaling_mode
             if scaling_policy_update_behavior is not None:
-                self._values[
-                    "scaling_policy_update_behavior"
-                ] = scaling_policy_update_behavior
+                self._values["scaling_policy_update_behavior"] = scaling_policy_update_behavior
             if scheduled_action_buffer_time is not None:
-                self._values[
-                    "scheduled_action_buffer_time"
-                ] = scheduled_action_buffer_time
+                self._values["scheduled_action_buffer_time"] = scheduled_action_buffer_time
 
         @builtins.property
         def max_capacity(self) -> jsii.Number:
@@ -794,15 +691,7 @@ class CfnScalingPlan(
         @builtins.property
         def target_tracking_configurations(
             self,
-        ) -> typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnScalingPlan.TargetTrackingConfigurationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]:
+        ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.TargetTrackingConfigurationProperty", _IResolvable_9ceae33e]]]:
             """``CfnScalingPlan.ScalingInstructionProperty.TargetTrackingConfigurations``.
 
             see
@@ -813,12 +702,7 @@ class CfnScalingPlan(
         @builtins.property
         def customized_load_metric_specification(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnScalingPlan.CustomizedLoadMetricSpecificationProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnScalingPlan.CustomizedLoadMetricSpecificationProperty", _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.ScalingInstructionProperty.CustomizedLoadMetricSpecification``.
 
             see
@@ -840,12 +724,7 @@ class CfnScalingPlan(
         @builtins.property
         def predefined_load_metric_specification(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnScalingPlan.PredefinedLoadMetricSpecificationProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnScalingPlan.PredefinedLoadMetricSpecificationProperty", _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.ScalingInstructionProperty.PredefinedLoadMetricSpecification``.
 
             see
@@ -980,22 +859,10 @@ class CfnScalingPlan(
             self,
             *,
             target_value: jsii.Number,
-            customized_scaling_metric_specification: typing.Optional[
-                typing.Union[
-                    "CfnScalingPlan.CustomizedScalingMetricSpecificationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
-            disable_scale_in: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            customized_scaling_metric_specification: typing.Optional[typing.Union["CfnScalingPlan.CustomizedScalingMetricSpecificationProperty", _IResolvable_9ceae33e]] = None,
+            disable_scale_in: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             estimated_instance_warmup: typing.Optional[jsii.Number] = None,
-            predefined_scaling_metric_specification: typing.Optional[
-                typing.Union[
-                    "CfnScalingPlan.PredefinedScalingMetricSpecificationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            predefined_scaling_metric_specification: typing.Optional[typing.Union["CfnScalingPlan.PredefinedScalingMetricSpecificationProperty", _IResolvable_9ceae33e]] = None,
             scale_in_cooldown: typing.Optional[jsii.Number] = None,
             scale_out_cooldown: typing.Optional[jsii.Number] = None,
         ) -> None:
@@ -1015,17 +882,13 @@ class CfnScalingPlan(
                 "target_value": target_value,
             }
             if customized_scaling_metric_specification is not None:
-                self._values[
-                    "customized_scaling_metric_specification"
-                ] = customized_scaling_metric_specification
+                self._values["customized_scaling_metric_specification"] = customized_scaling_metric_specification
             if disable_scale_in is not None:
                 self._values["disable_scale_in"] = disable_scale_in
             if estimated_instance_warmup is not None:
                 self._values["estimated_instance_warmup"] = estimated_instance_warmup
             if predefined_scaling_metric_specification is not None:
-                self._values[
-                    "predefined_scaling_metric_specification"
-                ] = predefined_scaling_metric_specification
+                self._values["predefined_scaling_metric_specification"] = predefined_scaling_metric_specification
             if scale_in_cooldown is not None:
                 self._values["scale_in_cooldown"] = scale_in_cooldown
             if scale_out_cooldown is not None:
@@ -1043,12 +906,7 @@ class CfnScalingPlan(
         @builtins.property
         def customized_scaling_metric_specification(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnScalingPlan.CustomizedScalingMetricSpecificationProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnScalingPlan.CustomizedScalingMetricSpecificationProperty", _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.CustomizedScalingMetricSpecification``.
 
             see
@@ -1079,12 +937,7 @@ class CfnScalingPlan(
         @builtins.property
         def predefined_scaling_metric_specification(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnScalingPlan.PredefinedScalingMetricSpecificationProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnScalingPlan.PredefinedScalingMetricSpecificationProperty", _IResolvable_9ceae33e]]:
             """``CfnScalingPlan.TargetTrackingConfigurationProperty.PredefinedScalingMetricSpecification``.
 
             see
@@ -1134,17 +987,8 @@ class CfnScalingPlanProps:
     def __init__(
         self,
         *,
-        application_source: typing.Union[
-            "CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e
-        ],
-        scaling_instructions: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ],
+        application_source: typing.Union["CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e],
+        scaling_instructions: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         """Properties for defining a ``AWS::AutoScalingPlans::ScalingPlan``.
 
@@ -1162,9 +1006,7 @@ class CfnScalingPlanProps:
     @builtins.property
     def application_source(
         self,
-    ) -> typing.Union[
-        "CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnScalingPlan.ApplicationSourceProperty", _IResolvable_9ceae33e]:
         """``AWS::AutoScalingPlans::ScalingPlan.ApplicationSource``.
 
         see
@@ -1175,14 +1017,7 @@ class CfnScalingPlanProps:
     @builtins.property
     def scaling_instructions(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[
-            typing.Union[
-                "CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e
-            ]
-        ],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnScalingPlan.ScalingInstructionProperty", _IResolvable_9ceae33e]]]:
         """``AWS::AutoScalingPlans::ScalingPlan.ScalingInstructions``.
 
         see
