@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -39,16 +39,7 @@ class CfnBudget(
         id: str,
         *,
         budget: typing.Union["BudgetDataProperty", _IResolvable_9ceae33e],
-        notifications_with_subscribers: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "NotificationWithSubscribersProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        notifications_with_subscribers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::Budgets::Budget``.
 
@@ -58,7 +49,8 @@ class CfnBudget(
         :param notifications_with_subscribers: ``AWS::Budgets::Budget.NotificationsWithSubscribers``.
         """
         props = CfnBudgetProps(
-            budget=budget, notifications_with_subscribers=notifications_with_subscribers
+            budget=budget,
+            notifications_with_subscribers=notifications_with_subscribers,
         )
 
         jsii.create(CfnBudget, self, [scope, id, props])
@@ -114,16 +106,7 @@ class CfnBudget(
     @jsii.member(jsii_name="notificationsWithSubscribers")
     def notifications_with_subscribers(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "NotificationWithSubscribersProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Budgets::Budget.NotificationsWithSubscribers``.
 
         see
@@ -134,16 +117,7 @@ class CfnBudget(
     @notifications_with_subscribers.setter
     def notifications_with_subscribers(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "NotificationWithSubscribersProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "notificationsWithSubscribers", value)
 
@@ -167,18 +141,12 @@ class CfnBudget(
             *,
             budget_type: str,
             time_unit: str,
-            budget_limit: typing.Optional[
-                typing.Union["CfnBudget.SpendProperty", _IResolvable_9ceae33e]
-            ] = None,
+            budget_limit: typing.Optional[typing.Union["CfnBudget.SpendProperty", _IResolvable_9ceae33e]] = None,
             budget_name: typing.Optional[str] = None,
             cost_filters: typing.Any = None,
-            cost_types: typing.Optional[
-                typing.Union["CfnBudget.CostTypesProperty", _IResolvable_9ceae33e]
-            ] = None,
+            cost_types: typing.Optional[typing.Union["CfnBudget.CostTypesProperty", _IResolvable_9ceae33e]] = None,
             planned_budget_limits: typing.Any = None,
-            time_period: typing.Optional[
-                typing.Union["CfnBudget.TimePeriodProperty", _IResolvable_9ceae33e]
-            ] = None,
+            time_period: typing.Optional[typing.Union["CfnBudget.TimePeriodProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param budget_type: ``CfnBudget.BudgetDataProperty.BudgetType``.
@@ -231,9 +199,7 @@ class CfnBudget(
         @builtins.property
         def budget_limit(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnBudget.SpendProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnBudget.SpendProperty", _IResolvable_9ceae33e]]:
             """``CfnBudget.BudgetDataProperty.BudgetLimit``.
 
             see
@@ -262,9 +228,7 @@ class CfnBudget(
         @builtins.property
         def cost_types(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnBudget.CostTypesProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnBudget.CostTypesProperty", _IResolvable_9ceae33e]]:
             """``CfnBudget.BudgetDataProperty.CostTypes``.
 
             see
@@ -284,9 +248,7 @@ class CfnBudget(
         @builtins.property
         def time_period(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnBudget.TimePeriodProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnBudget.TimePeriodProperty", _IResolvable_9ceae33e]]:
             """``CfnBudget.BudgetDataProperty.TimePeriod``.
 
             see
@@ -326,39 +288,17 @@ class CfnBudget(
         def __init__(
             self,
             *,
-            include_credit: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            include_discount: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            include_other_subscription: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            include_recurring: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            include_refund: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            include_subscription: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            include_support: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            include_tax: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            include_upfront: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            use_amortized: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            use_blended: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            include_credit: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_discount: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_other_subscription: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_recurring: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_refund: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_subscription: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_support: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_tax: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            include_upfront: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            use_amortized: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            use_blended: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param include_credit: ``CfnBudget.CostTypesProperty.IncludeCredit``.
@@ -624,15 +564,8 @@ class CfnBudget(
         def __init__(
             self,
             *,
-            notification: typing.Union[
-                "CfnBudget.NotificationProperty", _IResolvable_9ceae33e
-            ],
-            subscribers: typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["CfnBudget.SubscriberProperty", _IResolvable_9ceae33e]
-                ],
-            ],
+            notification: typing.Union["CfnBudget.NotificationProperty", _IResolvable_9ceae33e],
+            subscribers: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.SubscriberProperty", _IResolvable_9ceae33e]]],
         ) -> None:
             """
             :param notification: ``CfnBudget.NotificationWithSubscribersProperty.Notification``.
@@ -660,12 +593,7 @@ class CfnBudget(
         @builtins.property
         def subscribers(
             self,
-        ) -> typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnBudget.SubscriberProperty", _IResolvable_9ceae33e]
-            ],
-        ]:
+        ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.SubscriberProperty", _IResolvable_9ceae33e]]]:
             """``CfnBudget.NotificationWithSubscribersProperty.Subscribers``.
 
             see
@@ -848,17 +776,7 @@ class CfnBudgetProps:
         self,
         *,
         budget: typing.Union["CfnBudget.BudgetDataProperty", _IResolvable_9ceae33e],
-        notifications_with_subscribers: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnBudget.NotificationWithSubscribersProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        notifications_with_subscribers: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Budgets::Budget``.
 
@@ -872,9 +790,7 @@ class CfnBudgetProps:
             "budget": budget,
         }
         if notifications_with_subscribers is not None:
-            self._values[
-                "notifications_with_subscribers"
-            ] = notifications_with_subscribers
+            self._values["notifications_with_subscribers"] = notifications_with_subscribers
 
     @builtins.property
     def budget(
@@ -890,17 +806,7 @@ class CfnBudgetProps:
     @builtins.property
     def notifications_with_subscribers(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnBudget.NotificationWithSubscribersProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnBudget.NotificationWithSubscribersProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Budgets::Budget.NotificationsWithSubscribers``.
 
         see
