@@ -13,17 +13,27 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    Duration as _Duration_5170c158,
     IInspectable as _IInspectable_051e6ed8,
     IResource as _IResource_72f7ee7e,
     Resource as _Resource_884d0774,
     TreeInspector as _TreeInspector_154f5999,
 )
+from ..aws_cloudwatch import (
+    Metric as _Metric_53e89548,
+    MetricOptions as _MetricOptions_ad2c4d5d,
+    Unit as _Unit_e1b74f3c,
+)
 from ..aws_iam import (
     IGrantable as _IGrantable_0fcfc53a,
     IPrincipal as _IPrincipal_97126874,
     IRole as _IRole_e69bbae4,
     PolicyStatement as _PolicyStatement_f75dc775,
 )
+from ..aws_logs import (
+    LogRetentionRetryOptions as _LogRetentionRetryOptions_32a28927,
+    RetentionDays as _RetentionDays_bdc7ad1f,
+)
 from ..aws_sns import ITopic as _ITopic_ef0ebe0e
 
 
@@ -376,6 +386,37 @@ class ISlackChannelConfiguration(
         """
         ...
 
+    @jsii.member(jsii_name="metric")
+    def metric(
+        self,
+        metric_name: str,
+        *,
+        account: typing.Optional[str] = None,
+        color: typing.Optional[str] = None,
+        dimensions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
+        label: typing.Optional[str] = None,
+        period: typing.Optional[_Duration_5170c158] = None,
+        region: typing.Optional[str] = None,
+        statistic: typing.Optional[str] = None,
+        unit: typing.Optional[_Unit_e1b74f3c] = None,
+    ) -> _Metric_53e89548:
+        """Return the given named metric for this SlackChannelConfiguration.
+
+        :param metric_name: -
+        :param account: Account which this metric comes from. Default: - Deployment account.
+        :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
+        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
+        :param region: Region which this metric comes from. Default: - Deployment region.
+        :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
+        :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
+
+        stability
+        :stability: experimental
+        """
+        ...
+
 
 class _ISlackChannelConfigurationProxy(
     jsii.proxy_for(_IResource_72f7ee7e), jsii.proxy_for(_IGrantable_0fcfc53a)
@@ -438,6 +479,48 @@ class _ISlackChannelConfigurationProxy(
         """
         return jsii.invoke(self, "addToRolePolicy", [statement])
 
+    @jsii.member(jsii_name="metric")
+    def metric(
+        self,
+        metric_name: str,
+        *,
+        account: typing.Optional[str] = None,
+        color: typing.Optional[str] = None,
+        dimensions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
+        label: typing.Optional[str] = None,
+        period: typing.Optional[_Duration_5170c158] = None,
+        region: typing.Optional[str] = None,
+        statistic: typing.Optional[str] = None,
+        unit: typing.Optional[_Unit_e1b74f3c] = None,
+    ) -> _Metric_53e89548:
+        """Return the given named metric for this SlackChannelConfiguration.
+
+        :param metric_name: -
+        :param account: Account which this metric comes from. Default: - Deployment account.
+        :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
+        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
+        :param region: Region which this metric comes from. Default: - Deployment region.
+        :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
+        :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
+
+        stability
+        :stability: experimental
+        """
+        props = _MetricOptions_ad2c4d5d(
+            account=account,
+            color=color,
+            dimensions=dimensions,
+            label=label,
+            period=period,
+            region=region,
+            statistic=statistic,
+            unit=unit,
+        )
+
+        return jsii.invoke(self, "metric", [metric_name, props])
+
 
 @jsii.enum(jsii_type="monocdk-experiment.aws_chatbot.LoggingLevel")
 class LoggingLevel(enum.Enum):
@@ -488,6 +571,9 @@ class SlackChannelConfiguration(
         slack_channel_id: str,
         slack_workspace_id: str,
         logging_level: typing.Optional["LoggingLevel"] = None,
+        log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
+        log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_32a28927] = None,
+        log_retention_role: typing.Optional[_IRole_e69bbae4] = None,
         notification_topics: typing.Optional[typing.List[_ITopic_ef0ebe0e]] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
     ) -> None:
@@ -498,6 +584,9 @@ class SlackChannelConfiguration(
         :param slack_channel_id: The ID of the Slack channel. To get the ID, open Slack, right click on the channel name in the left pane, then choose Copy Link. The channel ID is the 9-character string at the end of the URL. For example, ABCBBLZZZ.
         :param slack_workspace_id: The ID of the Slack workspace authorized with AWS Chatbot. To get the workspace ID, you must perform the initial authorization flow with Slack in the AWS Chatbot console. Then you can copy and paste the workspace ID from the console. For more details, see steps 1-4 in Setting Up AWS Chatbot with Slack in the AWS Chatbot User Guide.
         :param logging_level: Specifies the logging level for this configuration. This property affects the log entries pushed to Amazon CloudWatch Logs. Default: LoggingLevel.NONE
+        :param log_retention: The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.INFINITE
+        :param log_retention_retry_options: When log retention is specified, a custom resource attempts to create the CloudWatch log group. These options control the retry policy when interacting with CloudWatch APIs. Default: - Default AWS SDK retry options.
+        :param log_retention_role: The IAM role for the Lambda function associated with the custom resource that sets the retention policy. Default: - A new role is created.
         :param notification_topics: The SNS topics that deliver notifications to AWS Chatbot. Default: None
         :param role: The permission role of Slack channel configuration. Default: - A role will be created.
 
@@ -509,6 +598,9 @@ class SlackChannelConfiguration(
             slack_channel_id=slack_channel_id,
             slack_workspace_id=slack_workspace_id,
             logging_level=logging_level,
+            log_retention=log_retention,
+            log_retention_retry_options=log_retention_retry_options,
+            log_retention_role=log_retention_role,
             notification_topics=notification_topics,
             role=role,
         )
@@ -534,6 +626,49 @@ class SlackChannelConfiguration(
         """
         return jsii.sinvoke(cls, "fromSlackChannelConfigurationArn", [scope, id, slack_channel_configuration_arn])
 
+    @jsii.member(jsii_name="metricAll")
+    @builtins.classmethod
+    def metric_all(
+        cls,
+        metric_name: str,
+        *,
+        account: typing.Optional[str] = None,
+        color: typing.Optional[str] = None,
+        dimensions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
+        label: typing.Optional[str] = None,
+        period: typing.Optional[_Duration_5170c158] = None,
+        region: typing.Optional[str] = None,
+        statistic: typing.Optional[str] = None,
+        unit: typing.Optional[_Unit_e1b74f3c] = None,
+    ) -> _Metric_53e89548:
+        """Return the given named metric for All SlackChannelConfigurations.
+
+        :param metric_name: -
+        :param account: Account which this metric comes from. Default: - Deployment account.
+        :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
+        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
+        :param region: Region which this metric comes from. Default: - Deployment region.
+        :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
+        :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
+
+        stability
+        :stability: experimental
+        """
+        props = _MetricOptions_ad2c4d5d(
+            account=account,
+            color=color,
+            dimensions=dimensions,
+            label=label,
+            period=period,
+            region=region,
+            statistic=statistic,
+            unit=unit,
+        )
+
+        return jsii.sinvoke(cls, "metricAll", [metric_name, props])
+
     @jsii.member(jsii_name="addToRolePolicy")
     def add_to_role_policy(self, statement: _PolicyStatement_f75dc775) -> None:
         """Adds extra permission to iam-role of Slack channel configuration.
@@ -545,6 +680,48 @@ class SlackChannelConfiguration(
         """
         return jsii.invoke(self, "addToRolePolicy", [statement])
 
+    @jsii.member(jsii_name="metric")
+    def metric(
+        self,
+        metric_name: str,
+        *,
+        account: typing.Optional[str] = None,
+        color: typing.Optional[str] = None,
+        dimensions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
+        label: typing.Optional[str] = None,
+        period: typing.Optional[_Duration_5170c158] = None,
+        region: typing.Optional[str] = None,
+        statistic: typing.Optional[str] = None,
+        unit: typing.Optional[_Unit_e1b74f3c] = None,
+    ) -> _Metric_53e89548:
+        """Return the given named metric for this SlackChannelConfiguration.
+
+        :param metric_name: -
+        :param account: Account which this metric comes from. Default: - Deployment account.
+        :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
+        :param dimensions: Dimensions of the metric. Default: - No dimensions.
+        :param label: Label for this metric when added to a Graph in a Dashboard. Default: - No label
+        :param period: The period over which the specified statistic is applied. Default: Duration.minutes(5)
+        :param region: Region which this metric comes from. Default: - Deployment region.
+        :param statistic: What function to use for aggregating. Can be one of the following: - "Minimum" | "min" - "Maximum" | "max" - "Average" | "avg" - "Sum" | "sum" - "SampleCount | "n" - "pNN.NN" Default: Average
+        :param unit: Unit used to filter the metric stream. Only refer to datums emitted to the metric stream with the given unit and ignore all others. Only useful when datums are being emitted to the same metric stream under different units. The default is to use all matric datums in the stream, regardless of unit, which is recommended in nearly all cases. CloudWatch does not honor this property for graphs. Default: - All metric datums in the given metric stream
+
+        stability
+        :stability: experimental
+        """
+        props = _MetricOptions_ad2c4d5d(
+            account=account,
+            color=color,
+            dimensions=dimensions,
+            label=label,
+            period=period,
+            region=region,
+            statistic=statistic,
+            unit=unit,
+        )
+
+        return jsii.invoke(self, "metric", [metric_name, props])
+
     @builtins.property
     @jsii.member(jsii_name="grantPrincipal")
     def grant_principal(self) -> _IPrincipal_97126874:
@@ -594,6 +771,9 @@ class SlackChannelConfiguration(
         "slack_channel_id": "slackChannelId",
         "slack_workspace_id": "slackWorkspaceId",
         "logging_level": "loggingLevel",
+        "log_retention": "logRetention",
+        "log_retention_retry_options": "logRetentionRetryOptions",
+        "log_retention_role": "logRetentionRole",
         "notification_topics": "notificationTopics",
         "role": "role",
     },
@@ -606,6 +786,9 @@ class SlackChannelConfigurationProps:
         slack_channel_id: str,
         slack_workspace_id: str,
         logging_level: typing.Optional["LoggingLevel"] = None,
+        log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
+        log_retention_retry_options: typing.Optional[_LogRetentionRetryOptions_32a28927] = None,
+        log_retention_role: typing.Optional[_IRole_e69bbae4] = None,
         notification_topics: typing.Optional[typing.List[_ITopic_ef0ebe0e]] = None,
         role: typing.Optional[_IRole_e69bbae4] = None,
     ) -> None:
@@ -615,12 +798,17 @@ class SlackChannelConfigurationProps:
         :param slack_channel_id: The ID of the Slack channel. To get the ID, open Slack, right click on the channel name in the left pane, then choose Copy Link. The channel ID is the 9-character string at the end of the URL. For example, ABCBBLZZZ.
         :param slack_workspace_id: The ID of the Slack workspace authorized with AWS Chatbot. To get the workspace ID, you must perform the initial authorization flow with Slack in the AWS Chatbot console. Then you can copy and paste the workspace ID from the console. For more details, see steps 1-4 in Setting Up AWS Chatbot with Slack in the AWS Chatbot User Guide.
         :param logging_level: Specifies the logging level for this configuration. This property affects the log entries pushed to Amazon CloudWatch Logs. Default: LoggingLevel.NONE
+        :param log_retention: The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.INFINITE
+        :param log_retention_retry_options: When log retention is specified, a custom resource attempts to create the CloudWatch log group. These options control the retry policy when interacting with CloudWatch APIs. Default: - Default AWS SDK retry options.
+        :param log_retention_role: The IAM role for the Lambda function associated with the custom resource that sets the retention policy. Default: - A new role is created.
         :param notification_topics: The SNS topics that deliver notifications to AWS Chatbot. Default: None
         :param role: The permission role of Slack channel configuration. Default: - A role will be created.
 
         stability
         :stability: experimental
         """
+        if isinstance(log_retention_retry_options, dict):
+            log_retention_retry_options = _LogRetentionRetryOptions_32a28927(**log_retention_retry_options)
         self._values = {
             "slack_channel_configuration_name": slack_channel_configuration_name,
             "slack_channel_id": slack_channel_id,
@@ -628,6 +816,12 @@ class SlackChannelConfigurationProps:
         }
         if logging_level is not None:
             self._values["logging_level"] = logging_level
+        if log_retention is not None:
+            self._values["log_retention"] = log_retention
+        if log_retention_retry_options is not None:
+            self._values["log_retention_retry_options"] = log_retention_retry_options
+        if log_retention_role is not None:
+            self._values["log_retention_role"] = log_retention_role
         if notification_topics is not None:
             self._values["notification_topics"] = notification_topics
         if role is not None:
@@ -683,6 +877,50 @@ class SlackChannelConfigurationProps:
         """
         return self._values.get("logging_level")
 
+    @builtins.property
+    def log_retention(self) -> typing.Optional[_RetentionDays_bdc7ad1f]:
+        """The number of days log events are kept in CloudWatch Logs.
+
+        When updating
+        this property, unsetting it doesn't remove the log retention policy. To
+        remove the retention policy, set the value to ``INFINITE``.
+
+        default
+        :default: logs.RetentionDays.INFINITE
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("log_retention")
+
+    @builtins.property
+    def log_retention_retry_options(
+        self,
+    ) -> typing.Optional[_LogRetentionRetryOptions_32a28927]:
+        """When log retention is specified, a custom resource attempts to create the CloudWatch log group.
+
+        These options control the retry policy when interacting with CloudWatch APIs.
+
+        default
+        :default: - Default AWS SDK retry options.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("log_retention_retry_options")
+
+    @builtins.property
+    def log_retention_role(self) -> typing.Optional[_IRole_e69bbae4]:
+        """The IAM role for the Lambda function associated with the custom resource that sets the retention policy.
+
+        default
+        :default: - A new role is created.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("log_retention_role")
+
     @builtins.property
     def notification_topics(self) -> typing.Optional[typing.List[_ITopic_ef0ebe0e]]:
         """The SNS topics that deliver notifications to AWS Chatbot.
