@@ -12,14 +12,14 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     IResource as _IResource_72f7ee7e,
     Resource as _Resource_884d0774,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_iam import Grant as _Grant_96af6d2d, IGrantable as _IGrantable_0fcfc53a
 
@@ -45,12 +45,7 @@ class CfnProfilingGroup(
         *,
         profiling_group_name: str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]]]] = None,
         compute_platform: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -156,12 +151,7 @@ class CfnProfilingGroup(
     @jsii.member(jsii_name="anomalyDetectionNotificationConfiguration")
     def anomaly_detection_notification_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration``.
 
         see
@@ -172,12 +162,7 @@ class CfnProfilingGroup(
     @anomaly_detection_notification_configuration.setter
     def anomaly_detection_notification_configuration(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
 
@@ -264,16 +249,7 @@ class CfnProfilingGroupProps:
         *,
         profiling_group_name: str,
         agent_permissions: typing.Any = None,
-        anomaly_detection_notification_configuration: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        anomaly_detection_notification_configuration: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]]]] = None,
         compute_platform: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -294,9 +270,7 @@ class CfnProfilingGroupProps:
         if agent_permissions is not None:
             self._values["agent_permissions"] = agent_permissions
         if anomaly_detection_notification_configuration is not None:
-            self._values[
-                "anomaly_detection_notification_configuration"
-            ] = anomaly_detection_notification_configuration
+            self._values["anomaly_detection_notification_configuration"] = anomaly_detection_notification_configuration
         if compute_platform is not None:
             self._values["compute_platform"] = compute_platform
         if tags is not None:
@@ -323,14 +297,7 @@ class CfnProfilingGroupProps:
     @builtins.property
     def anomaly_detection_notification_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration``.
 
         see
@@ -531,7 +498,8 @@ class ProfilingGroup(
         :stability: experimental
         """
         props = ProfilingGroupProps(
-            compute_platform=compute_platform, profiling_group_name=profiling_group_name
+            compute_platform=compute_platform,
+            profiling_group_name=profiling_group_name,
         )
 
         jsii.create(ProfilingGroup, self, [scope, id, props])
@@ -550,9 +518,7 @@ class ProfilingGroup(
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(
-            cls, "fromProfilingGroupArn", [scope, id, profiling_group_arn]
-        )
+        return jsii.sinvoke(cls, "fromProfilingGroupArn", [scope, id, profiling_group_arn])
 
     @jsii.member(jsii_name="fromProfilingGroupName")
     @builtins.classmethod
@@ -568,9 +534,7 @@ class ProfilingGroup(
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(
-            cls, "fromProfilingGroupName", [scope, id, profiling_group_name]
-        )
+        return jsii.sinvoke(cls, "fromProfilingGroupName", [scope, id, profiling_group_name])
 
     @jsii.member(jsii_name="grantPublish")
     def grant_publish(self, grantee: _IGrantable_0fcfc53a) -> _Grant_96af6d2d:
