@@ -13,12 +13,12 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
-    TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    IResource as _IResource_72f7ee7e,
     Resource as _Resource_884d0774,
     SecretValue as _SecretValue_99478b8b,
-    IResource as _IResource_72f7ee7e,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_s3 import IBucket as _IBucket_25bad983
 
@@ -45,12 +45,8 @@ class CfnGitHubRepository(
         repository_access_token: str,
         repository_name: str,
         repository_owner: str,
-        code: typing.Optional[
-            typing.Union["CodeProperty", _IResolvable_9ceae33e]
-        ] = None,
-        enable_issues: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        code: typing.Optional[typing.Union["CodeProperty", _IResolvable_9ceae33e]] = None,
+        enable_issues: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         is_private: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         repository_description: typing.Optional[str] = None,
     ) -> None:
@@ -348,12 +344,8 @@ class CfnGitHubRepositoryProps:
         repository_access_token: str,
         repository_name: str,
         repository_owner: str,
-        code: typing.Optional[
-            typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]
-        ] = None,
-        enable_issues: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        code: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]] = None,
+        enable_issues: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         is_private: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         repository_description: typing.Optional[str] = None,
     ) -> None:
@@ -414,9 +406,7 @@ class CfnGitHubRepositoryProps:
     @builtins.property
     def code(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_9ceae33e]]:
         """``AWS::CodeStar::GitHubRepository.Code``.
 
         see
