@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
-    TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
     CfnTag as _CfnTag_b4661f1a,
+    Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
     TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -42,11 +42,7 @@ class CfnApplication(
         *,
         application_name: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
-        resource_lifecycle_config: typing.Optional[
-            typing.Union[
-                "ApplicationResourceLifecycleConfigProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        resource_lifecycle_config: typing.Optional[typing.Union["ApplicationResourceLifecycleConfigProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::ElasticBeanstalk::Application``.
 
@@ -127,11 +123,7 @@ class CfnApplication(
     @jsii.member(jsii_name="resourceLifecycleConfig")
     def resource_lifecycle_config(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "ApplicationResourceLifecycleConfigProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["ApplicationResourceLifecycleConfigProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``.
 
         see
@@ -142,11 +134,7 @@ class CfnApplication(
     @resource_lifecycle_config.setter
     def resource_lifecycle_config(
         self,
-        value: typing.Optional[
-            typing.Union[
-                "ApplicationResourceLifecycleConfigProperty", _IResolvable_9ceae33e
-            ]
-        ],
+        value: typing.Optional[typing.Union["ApplicationResourceLifecycleConfigProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "resourceLifecycleConfig", value)
 
@@ -163,12 +151,7 @@ class CfnApplication(
             self,
             *,
             service_role: typing.Optional[str] = None,
-            version_lifecycle_config: typing.Optional[
-                typing.Union[
-                    "CfnApplication.ApplicationVersionLifecycleConfigProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            version_lifecycle_config: typing.Optional[typing.Union["CfnApplication.ApplicationVersionLifecycleConfigProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param service_role: ``CfnApplication.ApplicationResourceLifecycleConfigProperty.ServiceRole``.
@@ -195,12 +178,7 @@ class CfnApplication(
         @builtins.property
         def version_lifecycle_config(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnApplication.ApplicationVersionLifecycleConfigProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnApplication.ApplicationVersionLifecycleConfigProperty", _IResolvable_9ceae33e]]:
             """``CfnApplication.ApplicationResourceLifecycleConfigProperty.VersionLifecycleConfig``.
 
             see
@@ -228,14 +206,8 @@ class CfnApplication(
         def __init__(
             self,
             *,
-            max_age_rule: typing.Optional[
-                typing.Union["CfnApplication.MaxAgeRuleProperty", _IResolvable_9ceae33e]
-            ] = None,
-            max_count_rule: typing.Optional[
-                typing.Union[
-                    "CfnApplication.MaxCountRuleProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            max_age_rule: typing.Optional[typing.Union["CfnApplication.MaxAgeRuleProperty", _IResolvable_9ceae33e]] = None,
+            max_count_rule: typing.Optional[typing.Union["CfnApplication.MaxCountRuleProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param max_age_rule: ``CfnApplication.ApplicationVersionLifecycleConfigProperty.MaxAgeRule``.
@@ -253,9 +225,7 @@ class CfnApplication(
         @builtins.property
         def max_age_rule(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnApplication.MaxAgeRuleProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnApplication.MaxAgeRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnApplication.ApplicationVersionLifecycleConfigProperty.MaxAgeRule``.
 
             see
@@ -266,9 +236,7 @@ class CfnApplication(
         @builtins.property
         def max_count_rule(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnApplication.MaxCountRuleProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnApplication.MaxCountRuleProperty", _IResolvable_9ceae33e]]:
             """``CfnApplication.ApplicationVersionLifecycleConfigProperty.MaxCountRule``.
 
             see
@@ -300,9 +268,7 @@ class CfnApplication(
         def __init__(
             self,
             *,
-            delete_source_from_s3: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            delete_source_from_s3: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             max_age_in_days: typing.Optional[jsii.Number] = None,
         ) -> None:
@@ -375,9 +341,7 @@ class CfnApplication(
         def __init__(
             self,
             *,
-            delete_source_from_s3: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            delete_source_from_s3: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             max_count: typing.Optional[jsii.Number] = None,
         ) -> None:
@@ -453,12 +417,7 @@ class CfnApplicationProps:
         *,
         application_name: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
-        resource_lifecycle_config: typing.Optional[
-            typing.Union[
-                "CfnApplication.ApplicationResourceLifecycleConfigProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ] = None,
+        resource_lifecycle_config: typing.Optional[typing.Union["CfnApplication.ApplicationResourceLifecycleConfigProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::ElasticBeanstalk::Application``.
 
@@ -498,12 +457,7 @@ class CfnApplicationProps:
     @builtins.property
     def resource_lifecycle_config(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnApplication.ApplicationResourceLifecycleConfigProperty",
-            _IResolvable_9ceae33e,
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnApplication.ApplicationResourceLifecycleConfigProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticBeanstalk::Application.ResourceLifecycleConfig``.
 
         see
@@ -702,9 +656,7 @@ class CfnApplicationVersionProps:
         self,
         *,
         application_name: str,
-        source_bundle: typing.Union[
-            "CfnApplicationVersion.SourceBundleProperty", _IResolvable_9ceae33e
-        ],
+        source_bundle: typing.Union["CfnApplicationVersion.SourceBundleProperty", _IResolvable_9ceae33e],
         description: typing.Optional[str] = None,
     ) -> None:
         """Properties for defining a ``AWS::ElasticBeanstalk::ApplicationVersion``.
@@ -735,9 +687,7 @@ class CfnApplicationVersionProps:
     @builtins.property
     def source_bundle(
         self,
-    ) -> typing.Union[
-        "CfnApplicationVersion.SourceBundleProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnApplicationVersion.SourceBundleProperty", _IResolvable_9ceae33e]:
         """``AWS::ElasticBeanstalk::ApplicationVersion.SourceBundle``.
 
         see
@@ -788,21 +738,10 @@ class CfnConfigurationTemplate(
         application_name: str,
         description: typing.Optional[str] = None,
         environment_id: typing.Optional[str] = None,
-        option_settings: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "ConfigurationOptionSettingProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        option_settings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ConfigurationOptionSettingProperty", _IResolvable_9ceae33e]]]] = None,
         platform_arn: typing.Optional[str] = None,
         solution_stack_name: typing.Optional[str] = None,
-        source_configuration: typing.Optional[
-            typing.Union["SourceConfigurationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        source_configuration: typing.Optional[typing.Union["SourceConfigurationProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::ElasticBeanstalk::ConfigurationTemplate``.
 
@@ -905,16 +844,7 @@ class CfnConfigurationTemplate(
     @jsii.member(jsii_name="optionSettings")
     def option_settings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "ConfigurationOptionSettingProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ConfigurationOptionSettingProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticBeanstalk::ConfigurationTemplate.OptionSettings``.
 
         see
@@ -925,16 +855,7 @@ class CfnConfigurationTemplate(
     @option_settings.setter
     def option_settings(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "ConfigurationOptionSettingProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ConfigurationOptionSettingProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "optionSettings", value)
 
@@ -970,9 +891,7 @@ class CfnConfigurationTemplate(
     @jsii.member(jsii_name="sourceConfiguration")
     def source_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["SourceConfigurationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["SourceConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticBeanstalk::ConfigurationTemplate.SourceConfiguration``.
 
         see
@@ -983,9 +902,7 @@ class CfnConfigurationTemplate(
     @source_configuration.setter
     def source_configuration(
         self,
-        value: typing.Optional[
-            typing.Union["SourceConfigurationProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["SourceConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "sourceConfiguration", value)
 
@@ -1145,25 +1062,10 @@ class CfnConfigurationTemplateProps:
         application_name: str,
         description: typing.Optional[str] = None,
         environment_id: typing.Optional[str] = None,
-        option_settings: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnConfigurationTemplate.ConfigurationOptionSettingProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        option_settings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnConfigurationTemplate.ConfigurationOptionSettingProperty", _IResolvable_9ceae33e]]]] = None,
         platform_arn: typing.Optional[str] = None,
         solution_stack_name: typing.Optional[str] = None,
-        source_configuration: typing.Optional[
-            typing.Union[
-                "CfnConfigurationTemplate.SourceConfigurationProperty",
-                _IResolvable_9ceae33e,
-            ]
-        ] = None,
+        source_configuration: typing.Optional[typing.Union["CfnConfigurationTemplate.SourceConfigurationProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::ElasticBeanstalk::ConfigurationTemplate``.
 
@@ -1224,17 +1126,7 @@ class CfnConfigurationTemplateProps:
     @builtins.property
     def option_settings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnConfigurationTemplate.ConfigurationOptionSettingProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnConfigurationTemplate.ConfigurationOptionSettingProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticBeanstalk::ConfigurationTemplate.OptionSettings``.
 
         see
@@ -1263,12 +1155,7 @@ class CfnConfigurationTemplateProps:
     @builtins.property
     def source_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnConfigurationTemplate.SourceConfigurationProperty",
-            _IResolvable_9ceae33e,
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnConfigurationTemplate.SourceConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticBeanstalk::ConfigurationTemplate.SourceConfiguration``.
 
         see
@@ -1311,21 +1198,12 @@ class CfnEnvironment(
         cname_prefix: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
         environment_name: typing.Optional[str] = None,
-        option_settings: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["OptionSettingProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        option_settings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["OptionSettingProperty", _IResolvable_9ceae33e]]]] = None,
         platform_arn: typing.Optional[str] = None,
         solution_stack_name: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         template_name: typing.Optional[str] = None,
-        tier: typing.Optional[
-            typing.Union["TierProperty", _IResolvable_9ceae33e]
-        ] = None,
+        tier: typing.Optional[typing.Union["TierProperty", _IResolvable_9ceae33e]] = None,
         version_label: typing.Optional[str] = None,
     ) -> None:
         """Create a new ``AWS::ElasticBeanstalk::Environment``.
@@ -1470,12 +1348,7 @@ class CfnEnvironment(
     @jsii.member(jsii_name="optionSettings")
     def option_settings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["OptionSettingProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["OptionSettingProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticBeanstalk::Environment.OptionSettings``.
 
         see
@@ -1486,14 +1359,7 @@ class CfnEnvironment(
     @option_settings.setter
     def option_settings(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["OptionSettingProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["OptionSettingProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "optionSettings", value)
 
@@ -1749,23 +1615,12 @@ class CfnEnvironmentProps:
         cname_prefix: typing.Optional[str] = None,
         description: typing.Optional[str] = None,
         environment_name: typing.Optional[str] = None,
-        option_settings: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnEnvironment.OptionSettingProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        option_settings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironment.OptionSettingProperty", _IResolvable_9ceae33e]]]] = None,
         platform_arn: typing.Optional[str] = None,
         solution_stack_name: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
         template_name: typing.Optional[str] = None,
-        tier: typing.Optional[
-            typing.Union["CfnEnvironment.TierProperty", _IResolvable_9ceae33e]
-        ] = None,
+        tier: typing.Optional[typing.Union["CfnEnvironment.TierProperty", _IResolvable_9ceae33e]] = None,
         version_label: typing.Optional[str] = None,
     ) -> None:
         """Properties for defining a ``AWS::ElasticBeanstalk::Environment``.
@@ -1848,16 +1703,7 @@ class CfnEnvironmentProps:
     @builtins.property
     def option_settings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnEnvironment.OptionSettingProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnEnvironment.OptionSettingProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::ElasticBeanstalk::Environment.OptionSettings``.
 
         see
@@ -1904,9 +1750,7 @@ class CfnEnvironmentProps:
     @builtins.property
     def tier(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnEnvironment.TierProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnEnvironment.TierProperty", _IResolvable_9ceae33e]]:
         """``AWS::ElasticBeanstalk::Environment.Tier``.
 
         see
