@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -41,48 +41,20 @@ class CfnDomain(
         id: str,
         *,
         access_policies: typing.Any = None,
-        advanced_options: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ] = None,
-        advanced_security_options: typing.Optional[
-            typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]
-        ] = None,
-        cognito_options: typing.Optional[
-            typing.Union["CognitoOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
-        domain_endpoint_options: typing.Optional[
-            typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
+        advanced_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]] = None,
+        advanced_security_options: typing.Optional[typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]] = None,
+        cognito_options: typing.Optional[typing.Union["CognitoOptionsProperty", _IResolvable_9ceae33e]] = None,
+        domain_endpoint_options: typing.Optional[typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]] = None,
         domain_name: typing.Optional[str] = None,
-        ebs_options: typing.Optional[
-            typing.Union["EBSOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
-        elasticsearch_cluster_config: typing.Optional[
-            typing.Union["ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e]
-        ] = None,
+        ebs_options: typing.Optional[typing.Union["EBSOptionsProperty", _IResolvable_9ceae33e]] = None,
+        elasticsearch_cluster_config: typing.Optional[typing.Union["ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e]] = None,
         elasticsearch_version: typing.Optional[str] = None,
-        encryption_at_rest_options: typing.Optional[
-            typing.Union["EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
-        log_publishing_options: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.Mapping[
-                    str,
-                    typing.Union["LogPublishingOptionProperty", _IResolvable_9ceae33e],
-                ],
-            ]
-        ] = None,
-        node_to_node_encryption_options: typing.Optional[
-            typing.Union["NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
-        snapshot_options: typing.Optional[
-            typing.Union["SnapshotOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
+        encryption_at_rest_options: typing.Optional[typing.Union["EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]] = None,
+        log_publishing_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["LogPublishingOptionProperty", _IResolvable_9ceae33e]]]] = None,
+        node_to_node_encryption_options: typing.Optional[typing.Union["NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e]] = None,
+        snapshot_options: typing.Optional[typing.Union["SnapshotOptionsProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        vpc_options: typing.Optional[
-            typing.Union["VPCOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
+        vpc_options: typing.Optional[typing.Union["VPCOptionsProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::Elasticsearch::Domain``.
 
@@ -212,9 +184,7 @@ class CfnDomain(
     @advanced_options.setter
     def advanced_options(
         self,
-        value: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]],
     ) -> None:
         jsii.set(self, "advancedOptions", value)
 
@@ -222,9 +192,7 @@ class CfnDomain(
     @jsii.member(jsii_name="advancedSecurityOptions")
     def advanced_security_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.AdvancedSecurityOptions``.
 
         see
@@ -235,9 +203,7 @@ class CfnDomain(
     @advanced_security_options.setter
     def advanced_security_options(
         self,
-        value: typing.Optional[
-            typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "advancedSecurityOptions", value)
 
@@ -256,9 +222,7 @@ class CfnDomain(
     @cognito_options.setter
     def cognito_options(
         self,
-        value: typing.Optional[
-            typing.Union["CognitoOptionsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["CognitoOptionsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "cognitoOptions", value)
 
@@ -266,9 +230,7 @@ class CfnDomain(
     @jsii.member(jsii_name="domainEndpointOptions")
     def domain_endpoint_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.DomainEndpointOptions``.
 
         see
@@ -279,9 +241,7 @@ class CfnDomain(
     @domain_endpoint_options.setter
     def domain_endpoint_options(
         self,
-        value: typing.Optional[
-            typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["DomainEndpointOptionsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "domainEndpointOptions", value)
 
@@ -314,9 +274,7 @@ class CfnDomain(
     @ebs_options.setter
     def ebs_options(
         self,
-        value: typing.Optional[
-            typing.Union["EBSOptionsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["EBSOptionsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "ebsOptions", value)
 
@@ -324,9 +282,7 @@ class CfnDomain(
     @jsii.member(jsii_name="elasticsearchClusterConfig")
     def elasticsearch_cluster_config(
         self,
-    ) -> typing.Optional[
-        typing.Union["ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.ElasticsearchClusterConfig``.
 
         see
@@ -337,9 +293,7 @@ class CfnDomain(
     @elasticsearch_cluster_config.setter
     def elasticsearch_cluster_config(
         self,
-        value: typing.Optional[
-            typing.Union["ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "elasticsearchClusterConfig", value)
 
@@ -361,9 +315,7 @@ class CfnDomain(
     @jsii.member(jsii_name="encryptionAtRestOptions")
     def encryption_at_rest_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.EncryptionAtRestOptions``.
 
         see
@@ -374,9 +326,7 @@ class CfnDomain(
     @encryption_at_rest_options.setter
     def encryption_at_rest_options(
         self,
-        value: typing.Optional[
-            typing.Union["EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "encryptionAtRestOptions", value)
 
@@ -384,14 +334,7 @@ class CfnDomain(
     @jsii.member(jsii_name="logPublishingOptions")
     def log_publishing_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.Mapping[
-                str, typing.Union["LogPublishingOptionProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["LogPublishingOptionProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Elasticsearch::Domain.LogPublishingOptions``.
 
         see
@@ -402,15 +345,7 @@ class CfnDomain(
     @log_publishing_options.setter
     def log_publishing_options(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.Mapping[
-                    str,
-                    typing.Union["LogPublishingOptionProperty", _IResolvable_9ceae33e],
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["LogPublishingOptionProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "logPublishingOptions", value)
 
@@ -418,9 +353,7 @@ class CfnDomain(
     @jsii.member(jsii_name="nodeToNodeEncryptionOptions")
     def node_to_node_encryption_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.NodeToNodeEncryptionOptions``.
 
         see
@@ -431,9 +364,7 @@ class CfnDomain(
     @node_to_node_encryption_options.setter
     def node_to_node_encryption_options(
         self,
-        value: typing.Optional[
-            typing.Union["NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "nodeToNodeEncryptionOptions", value)
 
@@ -441,9 +372,7 @@ class CfnDomain(
     @jsii.member(jsii_name="snapshotOptions")
     def snapshot_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["SnapshotOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["SnapshotOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.SnapshotOptions``.
 
         see
@@ -454,9 +383,7 @@ class CfnDomain(
     @snapshot_options.setter
     def snapshot_options(
         self,
-        value: typing.Optional[
-            typing.Union["SnapshotOptionsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["SnapshotOptionsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "snapshotOptions", value)
 
@@ -475,9 +402,7 @@ class CfnDomain(
     @vpc_options.setter
     def vpc_options(
         self,
-        value: typing.Optional[
-            typing.Union["VPCOptionsProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["VPCOptionsProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "vpcOptions", value)
 
@@ -495,14 +420,8 @@ class CfnDomain(
             self,
             *,
             enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-            internal_user_database_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
-            master_user_options: typing.Optional[
-                typing.Union[
-                    "CfnDomain.MasterUserOptionsProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            internal_user_database_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+            master_user_options: typing.Optional[typing.Union["CfnDomain.MasterUserOptionsProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param enabled: ``CfnDomain.AdvancedSecurityOptionsInputProperty.Enabled``.
@@ -516,9 +435,7 @@ class CfnDomain(
             if enabled is not None:
                 self._values["enabled"] = enabled
             if internal_user_database_enabled is not None:
-                self._values[
-                    "internal_user_database_enabled"
-                ] = internal_user_database_enabled
+                self._values["internal_user_database_enabled"] = internal_user_database_enabled
             if master_user_options is not None:
                 self._values["master_user_options"] = master_user_options
 
@@ -545,9 +462,7 @@ class CfnDomain(
         @builtins.property
         def master_user_options(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnDomain.MasterUserOptionsProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnDomain.MasterUserOptionsProperty", _IResolvable_9ceae33e]]:
             """``CfnDomain.AdvancedSecurityOptionsInputProperty.MasterUserOptions``.
 
             see
@@ -663,9 +578,7 @@ class CfnDomain(
         def __init__(
             self,
             *,
-            enforce_https: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            enforce_https: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             tls_security_policy: typing.Optional[str] = None,
         ) -> None:
             """
@@ -726,9 +639,7 @@ class CfnDomain(
         def __init__(
             self,
             *,
-            ebs_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            ebs_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             iops: typing.Optional[jsii.Number] = None,
             volume_size: typing.Optional[jsii.Number] = None,
             volume_type: typing.Optional[str] = None,
@@ -819,20 +730,12 @@ class CfnDomain(
             self,
             *,
             dedicated_master_count: typing.Optional[jsii.Number] = None,
-            dedicated_master_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            dedicated_master_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             dedicated_master_type: typing.Optional[str] = None,
             instance_count: typing.Optional[jsii.Number] = None,
             instance_type: typing.Optional[str] = None,
-            zone_awareness_config: typing.Optional[
-                typing.Union[
-                    "CfnDomain.ZoneAwarenessConfigProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
-            zone_awareness_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            zone_awareness_config: typing.Optional[typing.Union["CfnDomain.ZoneAwarenessConfigProperty", _IResolvable_9ceae33e]] = None,
+            zone_awareness_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param dedicated_master_count: ``CfnDomain.ElasticsearchClusterConfigProperty.DedicatedMasterCount``.
@@ -912,9 +815,7 @@ class CfnDomain(
         @builtins.property
         def zone_awareness_config(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnDomain.ZoneAwarenessConfigProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnDomain.ZoneAwarenessConfigProperty", _IResolvable_9ceae33e]]:
             """``CfnDomain.ElasticsearchClusterConfigProperty.ZoneAwarenessConfig``.
 
             see
@@ -1022,9 +923,7 @@ class CfnDomain(
             """
             self._values = {}
             if cloud_watch_logs_log_group_arn is not None:
-                self._values[
-                    "cloud_watch_logs_log_group_arn"
-                ] = cloud_watch_logs_log_group_arn
+                self._values["cloud_watch_logs_log_group_arn"] = cloud_watch_logs_log_group_arn
             if enabled is not None:
                 self._values["enabled"] = enabled
 
@@ -1186,9 +1085,7 @@ class CfnDomain(
             """
             self._values = {}
             if automated_snapshot_start_hour is not None:
-                self._values[
-                    "automated_snapshot_start_hour"
-                ] = automated_snapshot_start_hour
+                self._values["automated_snapshot_start_hour"] = automated_snapshot_start_hour
 
         @builtins.property
         def automated_snapshot_start_hour(self) -> typing.Optional[jsii.Number]:
@@ -1333,60 +1230,20 @@ class CfnDomainProps:
         self,
         *,
         access_policies: typing.Any = None,
-        advanced_options: typing.Optional[
-            typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]
-        ] = None,
-        advanced_security_options: typing.Optional[
-            typing.Union[
-                "CfnDomain.AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
-        cognito_options: typing.Optional[
-            typing.Union["CfnDomain.CognitoOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
-        domain_endpoint_options: typing.Optional[
-            typing.Union[
-                "CfnDomain.DomainEndpointOptionsProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        advanced_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, str]]] = None,
+        advanced_security_options: typing.Optional[typing.Union["CfnDomain.AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]] = None,
+        cognito_options: typing.Optional[typing.Union["CfnDomain.CognitoOptionsProperty", _IResolvable_9ceae33e]] = None,
+        domain_endpoint_options: typing.Optional[typing.Union["CfnDomain.DomainEndpointOptionsProperty", _IResolvable_9ceae33e]] = None,
         domain_name: typing.Optional[str] = None,
-        ebs_options: typing.Optional[
-            typing.Union["CfnDomain.EBSOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
-        elasticsearch_cluster_config: typing.Optional[
-            typing.Union[
-                "CfnDomain.ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        ebs_options: typing.Optional[typing.Union["CfnDomain.EBSOptionsProperty", _IResolvable_9ceae33e]] = None,
+        elasticsearch_cluster_config: typing.Optional[typing.Union["CfnDomain.ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e]] = None,
         elasticsearch_version: typing.Optional[str] = None,
-        encryption_at_rest_options: typing.Optional[
-            typing.Union[
-                "CfnDomain.EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
-        log_publishing_options: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.Mapping[
-                    str,
-                    typing.Union[
-                        "CfnDomain.LogPublishingOptionProperty", _IResolvable_9ceae33e
-                    ],
-                ],
-            ]
-        ] = None,
-        node_to_node_encryption_options: typing.Optional[
-            typing.Union[
-                "CfnDomain.NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
-        snapshot_options: typing.Optional[
-            typing.Union["CfnDomain.SnapshotOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
+        encryption_at_rest_options: typing.Optional[typing.Union["CfnDomain.EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]] = None,
+        log_publishing_options: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["CfnDomain.LogPublishingOptionProperty", _IResolvable_9ceae33e]]]] = None,
+        node_to_node_encryption_options: typing.Optional[typing.Union["CfnDomain.NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e]] = None,
+        snapshot_options: typing.Optional[typing.Union["CfnDomain.SnapshotOptionsProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        vpc_options: typing.Optional[
-            typing.Union["CfnDomain.VPCOptionsProperty", _IResolvable_9ceae33e]
-        ] = None,
+        vpc_options: typing.Optional[typing.Union["CfnDomain.VPCOptionsProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Elasticsearch::Domain``.
 
@@ -1433,9 +1290,7 @@ class CfnDomainProps:
         if log_publishing_options is not None:
             self._values["log_publishing_options"] = log_publishing_options
         if node_to_node_encryption_options is not None:
-            self._values[
-                "node_to_node_encryption_options"
-            ] = node_to_node_encryption_options
+            self._values["node_to_node_encryption_options"] = node_to_node_encryption_options
         if snapshot_options is not None:
             self._values["snapshot_options"] = snapshot_options
         if tags is not None:
@@ -1466,11 +1321,7 @@ class CfnDomainProps:
     @builtins.property
     def advanced_security_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnDomain.AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.AdvancedSecurityOptionsInputProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.AdvancedSecurityOptions``.
 
         see
@@ -1481,9 +1332,7 @@ class CfnDomainProps:
     @builtins.property
     def cognito_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnDomain.CognitoOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.CognitoOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.CognitoOptions``.
 
         see
@@ -1494,9 +1343,7 @@ class CfnDomainProps:
     @builtins.property
     def domain_endpoint_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnDomain.DomainEndpointOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.DomainEndpointOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.DomainEndpointOptions``.
 
         see
@@ -1516,9 +1363,7 @@ class CfnDomainProps:
     @builtins.property
     def ebs_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnDomain.EBSOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.EBSOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.EBSOptions``.
 
         see
@@ -1529,11 +1374,7 @@ class CfnDomainProps:
     @builtins.property
     def elasticsearch_cluster_config(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnDomain.ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.ElasticsearchClusterConfigProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.ElasticsearchClusterConfig``.
 
         see
@@ -1553,9 +1394,7 @@ class CfnDomainProps:
     @builtins.property
     def encryption_at_rest_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnDomain.EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.EncryptionAtRestOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.EncryptionAtRestOptions``.
 
         see
@@ -1566,17 +1405,7 @@ class CfnDomainProps:
     @builtins.property
     def log_publishing_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.Mapping[
-                str,
-                typing.Union[
-                    "CfnDomain.LogPublishingOptionProperty", _IResolvable_9ceae33e
-                ],
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.Mapping[str, typing.Union["CfnDomain.LogPublishingOptionProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::Elasticsearch::Domain.LogPublishingOptions``.
 
         see
@@ -1587,11 +1416,7 @@ class CfnDomainProps:
     @builtins.property
     def node_to_node_encryption_options(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            "CfnDomain.NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.NodeToNodeEncryptionOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.NodeToNodeEncryptionOptions``.
 
         see
@@ -1602,9 +1427,7 @@ class CfnDomainProps:
     @builtins.property
     def snapshot_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnDomain.SnapshotOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.SnapshotOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.SnapshotOptions``.
 
         see
@@ -1624,9 +1447,7 @@ class CfnDomainProps:
     @builtins.property
     def vpc_options(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnDomain.VPCOptionsProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDomain.VPCOptionsProperty", _IResolvable_9ceae33e]]:
         """``AWS::Elasticsearch::Domain.VPCOptions``.
 
         see
