@@ -12,11 +12,11 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
+    CfnTag as _CfnTag_b4661f1a,
     Construct as _Construct_f50a3f53,
-    TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
-    CfnTag as _CfnTag_b4661f1a,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -207,12 +207,7 @@ class CfnAssessmentTemplate(
         duration_in_seconds: jsii.Number,
         rules_package_arns: typing.List[str],
         assessment_template_name: typing.Optional[str] = None,
-        user_attributes_for_findings: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-            ]
-        ] = None,
+        user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
     ) -> None:
         """Create a new ``AWS::Inspector::AssessmentTemplate``.
 
@@ -334,12 +329,7 @@ class CfnAssessmentTemplate(
     @jsii.member(jsii_name="userAttributesForFindings")
     def user_attributes_for_findings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
@@ -350,12 +340,7 @@ class CfnAssessmentTemplate(
     @user_attributes_for_findings.setter
     def user_attributes_for_findings(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]],
     ) -> None:
         jsii.set(self, "userAttributesForFindings", value)
 
@@ -379,12 +364,7 @@ class CfnAssessmentTemplateProps:
         duration_in_seconds: jsii.Number,
         rules_package_arns: typing.List[str],
         assessment_template_name: typing.Optional[str] = None,
-        user_attributes_for_findings: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-            ]
-        ] = None,
+        user_attributes_for_findings: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::Inspector::AssessmentTemplate``.
 
@@ -446,12 +426,7 @@ class CfnAssessmentTemplateProps:
     @builtins.property
     def user_attributes_for_findings(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]]:
         """``AWS::Inspector::AssessmentTemplate.UserAttributesForFindings``.
 
         see
@@ -490,10 +465,7 @@ class CfnResourceGroup(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        resource_group_tags: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-        ],
+        resource_group_tags: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]],
     ) -> None:
         """Create a new ``AWS::Inspector::ResourceGroup``.
 
@@ -549,10 +521,7 @@ class CfnResourceGroup(
     @jsii.member(jsii_name="resourceGroupTags")
     def resource_group_tags(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         see
@@ -563,10 +532,7 @@ class CfnResourceGroup(
     @resource_group_tags.setter
     def resource_group_tags(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]],
     ) -> None:
         jsii.set(self, "resourceGroupTags", value)
 
@@ -580,10 +546,7 @@ class CfnResourceGroupProps:
     def __init__(
         self,
         *,
-        resource_group_tags: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-        ],
+        resource_group_tags: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]],
     ) -> None:
         """Properties for defining a ``AWS::Inspector::ResourceGroup``.
 
@@ -599,10 +562,7 @@ class CfnResourceGroupProps:
     @builtins.property
     def resource_group_tags(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union[_IResolvable_9ceae33e, _CfnTag_b4661f1a]]]:
         """``AWS::Inspector::ResourceGroup.ResourceGroupTags``.
 
         see
