@@ -11,25 +11,25 @@ import publication
 from .._jsii import *
 
 from .. import (
-    Resource as _Resource_884d0774,
-    Construct as _Construct_f50a3f53,
-    RemovalPolicy as _RemovalPolicy_5986e9f3,
     CfnResource as _CfnResource_7760e8e4,
-    TreeInspector as _TreeInspector_154f5999,
+    CfnTag as _CfnTag_b4661f1a,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
-    CfnTag as _CfnTag_b4661f1a,
-    TagManager as _TagManager_2508893f,
     IResource as _IResource_72f7ee7e,
+    RemovalPolicy as _RemovalPolicy_5986e9f3,
+    Resource as _Resource_884d0774,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 from ..aws_iam import (
     AddToResourcePolicyResult as _AddToResourcePolicyResult_d2a345d1,
-    PolicyStatement as _PolicyStatement_f75dc775,
     Grant as _Grant_96af6d2d,
     IGrantable as _IGrantable_0fcfc53a,
-    PolicyDocument as _PolicyDocument_1d1bca11,
-    PrincipalBase as _PrincipalBase_e4459eeb,
     IPrincipal as _IPrincipal_97126874,
+    PolicyDocument as _PolicyDocument_1d1bca11,
+    PolicyStatement as _PolicyStatement_f75dc775,
+    PrincipalBase as _PrincipalBase_e4459eeb,
     PrincipalPolicyFragment as _PrincipalPolicyFragment_621f702c,
 )
 
@@ -334,9 +334,7 @@ class CfnKey(
         key_policy: typing.Any,
         description: typing.Optional[str] = None,
         enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        enable_key_rotation: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        enable_key_rotation: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         key_usage: typing.Optional[str] = None,
         pending_window_in_days: typing.Optional[jsii.Number] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
@@ -526,9 +524,7 @@ class CfnKeyProps:
         key_policy: typing.Any,
         description: typing.Optional[str] = None,
         enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
-        enable_key_rotation: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        enable_key_rotation: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         key_usage: typing.Optional[str] = None,
         pending_window_in_days: typing.Optional[jsii.Number] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
