@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -38,14 +38,7 @@ class CfnDataLakeSettings(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        admins: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        admins: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::LakeFormation::DataLakeSettings``.
 
@@ -92,14 +85,7 @@ class CfnDataLakeSettings(
     @jsii.member(jsii_name="admins")
     def admins(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::LakeFormation::DataLakeSettings.Admins``.
 
         see
@@ -110,14 +96,7 @@ class CfnDataLakeSettings(
     @admins.setter
     def admins(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "admins", value)
 
@@ -138,9 +117,7 @@ class CfnDataLakeSettings(
             """
             self._values = {}
             if data_lake_principal_identifier is not None:
-                self._values[
-                    "data_lake_principal_identifier"
-                ] = data_lake_principal_identifier
+                self._values["data_lake_principal_identifier"] = data_lake_principal_identifier
 
         @builtins.property
         def data_lake_principal_identifier(self) -> typing.Optional[str]:
@@ -172,17 +149,7 @@ class CfnDataLakeSettingsProps:
     def __init__(
         self,
         *,
-        admins: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnDataLakeSettings.DataLakePrincipalProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        admins: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnDataLakeSettings.DataLakePrincipalProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::LakeFormation::DataLakeSettings``.
 
@@ -198,17 +165,7 @@ class CfnDataLakeSettingsProps:
     @builtins.property
     def admins(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnDataLakeSettings.DataLakePrincipalProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnDataLakeSettings.DataLakePrincipalProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::LakeFormation::DataLakeSettings.Admins``.
 
         see
@@ -247,9 +204,7 @@ class CfnPermissions(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        data_lake_principal: typing.Union[
-            "DataLakePrincipalProperty", _IResolvable_9ceae33e
-        ],
+        data_lake_principal: typing.Union["DataLakePrincipalProperty", _IResolvable_9ceae33e],
         resource: typing.Union["ResourceProperty", _IResolvable_9ceae33e],
         permissions: typing.Optional[typing.List[str]] = None,
         permissions_with_grant_option: typing.Optional[typing.List[str]] = None,
@@ -423,9 +378,7 @@ class CfnPermissions(
             """
             self._values = {}
             if data_lake_principal_identifier is not None:
-                self._values[
-                    "data_lake_principal_identifier"
-                ] = data_lake_principal_identifier
+                self._values["data_lake_principal_identifier"] = data_lake_principal_identifier
 
         @builtins.property
         def data_lake_principal_identifier(self) -> typing.Optional[str]:
@@ -535,27 +488,10 @@ class CfnPermissions(
         def __init__(
             self,
             *,
-            database_resource: typing.Optional[
-                typing.Union[
-                    "CfnPermissions.DatabaseResourceProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
-            data_location_resource: typing.Optional[
-                typing.Union[
-                    "CfnPermissions.DataLocationResourceProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
-            table_resource: typing.Optional[
-                typing.Union[
-                    "CfnPermissions.TableResourceProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
-            table_with_columns_resource: typing.Optional[
-                typing.Union[
-                    "CfnPermissions.TableWithColumnsResourceProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            database_resource: typing.Optional[typing.Union["CfnPermissions.DatabaseResourceProperty", _IResolvable_9ceae33e]] = None,
+            data_location_resource: typing.Optional[typing.Union["CfnPermissions.DataLocationResourceProperty", _IResolvable_9ceae33e]] = None,
+            table_resource: typing.Optional[typing.Union["CfnPermissions.TableResourceProperty", _IResolvable_9ceae33e]] = None,
+            table_with_columns_resource: typing.Optional[typing.Union["CfnPermissions.TableWithColumnsResourceProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param database_resource: ``CfnPermissions.ResourceProperty.DatabaseResource``.
@@ -574,18 +510,12 @@ class CfnPermissions(
             if table_resource is not None:
                 self._values["table_resource"] = table_resource
             if table_with_columns_resource is not None:
-                self._values[
-                    "table_with_columns_resource"
-                ] = table_with_columns_resource
+                self._values["table_with_columns_resource"] = table_with_columns_resource
 
         @builtins.property
         def database_resource(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnPermissions.DatabaseResourceProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnPermissions.DatabaseResourceProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.ResourceProperty.DatabaseResource``.
 
             see
@@ -596,11 +526,7 @@ class CfnPermissions(
         @builtins.property
         def data_location_resource(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnPermissions.DataLocationResourceProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnPermissions.DataLocationResourceProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.ResourceProperty.DataLocationResource``.
 
             see
@@ -611,9 +537,7 @@ class CfnPermissions(
         @builtins.property
         def table_resource(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnPermissions.TableResourceProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnPermissions.TableResourceProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.ResourceProperty.TableResource``.
 
             see
@@ -624,11 +548,7 @@ class CfnPermissions(
         @builtins.property
         def table_with_columns_resource(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnPermissions.TableWithColumnsResourceProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnPermissions.TableWithColumnsResourceProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.ResourceProperty.TableWithColumnsResource``.
 
             see
@@ -716,11 +636,7 @@ class CfnPermissions(
             self,
             *,
             column_names: typing.Optional[typing.List[str]] = None,
-            column_wildcard: typing.Optional[
-                typing.Union[
-                    "CfnPermissions.ColumnWildcardProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            column_wildcard: typing.Optional[typing.Union["CfnPermissions.ColumnWildcardProperty", _IResolvable_9ceae33e]] = None,
             database_name: typing.Optional[str] = None,
             name: typing.Optional[str] = None,
         ) -> None:
@@ -755,9 +671,7 @@ class CfnPermissions(
         @builtins.property
         def column_wildcard(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnPermissions.ColumnWildcardProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnPermissions.ColumnWildcardProperty", _IResolvable_9ceae33e]]:
             """``CfnPermissions.TableWithColumnsResourceProperty.ColumnWildcard``.
 
             see
@@ -809,12 +723,8 @@ class CfnPermissionsProps:
     def __init__(
         self,
         *,
-        data_lake_principal: typing.Union[
-            "CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e
-        ],
-        resource: typing.Union[
-            "CfnPermissions.ResourceProperty", _IResolvable_9ceae33e
-        ],
+        data_lake_principal: typing.Union["CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e],
+        resource: typing.Union["CfnPermissions.ResourceProperty", _IResolvable_9ceae33e],
         permissions: typing.Optional[typing.List[str]] = None,
         permissions_with_grant_option: typing.Optional[typing.List[str]] = None,
     ) -> None:
@@ -835,16 +745,12 @@ class CfnPermissionsProps:
         if permissions is not None:
             self._values["permissions"] = permissions
         if permissions_with_grant_option is not None:
-            self._values[
-                "permissions_with_grant_option"
-            ] = permissions_with_grant_option
+            self._values["permissions_with_grant_option"] = permissions_with_grant_option
 
     @builtins.property
     def data_lake_principal(
         self,
-    ) -> typing.Union[
-        "CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e
-    ]:
+    ) -> typing.Union["CfnPermissions.DataLakePrincipalProperty", _IResolvable_9ceae33e]:
         """``AWS::LakeFormation::Permissions.DataLakePrincipal``.
 
         see
