@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -38,13 +38,9 @@ class CfnMember(
         scope: _Construct_f50a3f53,
         id: str,
         *,
-        member_configuration: typing.Union[
-            "MemberConfigurationProperty", _IResolvable_9ceae33e
-        ],
+        member_configuration: typing.Union["MemberConfigurationProperty", _IResolvable_9ceae33e],
         invitation_id: typing.Optional[str] = None,
-        network_configuration: typing.Optional[
-            typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        network_configuration: typing.Optional[typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
         network_id: typing.Optional[str] = None,
     ) -> None:
         """Create a new ``AWS::ManagedBlockchain::Member``.
@@ -150,9 +146,7 @@ class CfnMember(
     @jsii.member(jsii_name="networkConfiguration")
     def network_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::ManagedBlockchain::Member.NetworkConfiguration``.
 
         see
@@ -163,9 +157,7 @@ class CfnMember(
     @network_configuration.setter
     def network_configuration(
         self,
-        value: typing.Optional[
-            typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["NetworkConfigurationProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "networkConfiguration", value)
 
@@ -269,12 +261,7 @@ class CfnMember(
             *,
             name: str,
             description: typing.Optional[str] = None,
-            member_framework_configuration: typing.Optional[
-                typing.Union[
-                    "CfnMember.MemberFrameworkConfigurationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            member_framework_configuration: typing.Optional[typing.Union["CfnMember.MemberFrameworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param name: ``CfnMember.MemberConfigurationProperty.Name``.
@@ -290,9 +277,7 @@ class CfnMember(
             if description is not None:
                 self._values["description"] = description
             if member_framework_configuration is not None:
-                self._values[
-                    "member_framework_configuration"
-                ] = member_framework_configuration
+                self._values["member_framework_configuration"] = member_framework_configuration
 
         @builtins.property
         def name(self) -> str:
@@ -315,11 +300,7 @@ class CfnMember(
         @builtins.property
         def member_framework_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnMember.MemberFrameworkConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnMember.MemberFrameworkConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.MemberConfigurationProperty.MemberFrameworkConfiguration``.
 
             see
@@ -398,11 +379,7 @@ class CfnMember(
         def __init__(
             self,
             *,
-            member_fabric_configuration: typing.Optional[
-                typing.Union[
-                    "CfnMember.MemberFabricConfigurationProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            member_fabric_configuration: typing.Optional[typing.Union["CfnMember.MemberFabricConfigurationProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param member_fabric_configuration: ``CfnMember.MemberFrameworkConfigurationProperty.MemberFabricConfiguration``.
@@ -412,18 +389,12 @@ class CfnMember(
             """
             self._values = {}
             if member_fabric_configuration is not None:
-                self._values[
-                    "member_fabric_configuration"
-                ] = member_fabric_configuration
+                self._values["member_fabric_configuration"] = member_fabric_configuration
 
         @builtins.property
         def member_fabric_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnMember.MemberFabricConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnMember.MemberFabricConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.MemberFrameworkConfigurationProperty.MemberFabricConfiguration``.
 
             see
@@ -461,16 +432,9 @@ class CfnMember(
             framework: str,
             framework_version: str,
             name: str,
-            voting_policy: typing.Union[
-                "CfnMember.VotingPolicyProperty", _IResolvable_9ceae33e
-            ],
+            voting_policy: typing.Union["CfnMember.VotingPolicyProperty", _IResolvable_9ceae33e],
             description: typing.Optional[str] = None,
-            network_framework_configuration: typing.Optional[
-                typing.Union[
-                    "CfnMember.NetworkFrameworkConfigurationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            network_framework_configuration: typing.Optional[typing.Union["CfnMember.NetworkFrameworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param framework: ``CfnMember.NetworkConfigurationProperty.Framework``.
@@ -492,9 +456,7 @@ class CfnMember(
             if description is not None:
                 self._values["description"] = description
             if network_framework_configuration is not None:
-                self._values[
-                    "network_framework_configuration"
-                ] = network_framework_configuration
+                self._values["network_framework_configuration"] = network_framework_configuration
 
         @builtins.property
         def framework(self) -> str:
@@ -546,11 +508,7 @@ class CfnMember(
         @builtins.property
         def network_framework_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnMember.NetworkFrameworkConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnMember.NetworkFrameworkConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.NetworkConfigurationProperty.NetworkFrameworkConfiguration``.
 
             see
@@ -615,12 +573,7 @@ class CfnMember(
         def __init__(
             self,
             *,
-            network_fabric_configuration: typing.Optional[
-                typing.Union[
-                    "CfnMember.NetworkFabricConfigurationProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ] = None,
+            network_fabric_configuration: typing.Optional[typing.Union["CfnMember.NetworkFabricConfigurationProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param network_fabric_configuration: ``CfnMember.NetworkFrameworkConfigurationProperty.NetworkFabricConfiguration``.
@@ -630,18 +583,12 @@ class CfnMember(
             """
             self._values = {}
             if network_fabric_configuration is not None:
-                self._values[
-                    "network_fabric_configuration"
-                ] = network_fabric_configuration
+                self._values["network_fabric_configuration"] = network_fabric_configuration
 
         @builtins.property
         def network_fabric_configuration(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnMember.NetworkFabricConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnMember.NetworkFabricConfigurationProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.NetworkFrameworkConfigurationProperty.NetworkFabricConfiguration``.
 
             see
@@ -669,11 +616,7 @@ class CfnMember(
         def __init__(
             self,
             *,
-            approval_threshold_policy: typing.Optional[
-                typing.Union[
-                    "CfnMember.ApprovalThresholdPolicyProperty", _IResolvable_9ceae33e
-                ]
-            ] = None,
+            approval_threshold_policy: typing.Optional[typing.Union["CfnMember.ApprovalThresholdPolicyProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param approval_threshold_policy: ``CfnMember.VotingPolicyProperty.ApprovalThresholdPolicy``.
@@ -688,11 +631,7 @@ class CfnMember(
         @builtins.property
         def approval_threshold_policy(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                "CfnMember.ApprovalThresholdPolicyProperty", _IResolvable_9ceae33e
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnMember.ApprovalThresholdPolicyProperty", _IResolvable_9ceae33e]]:
             """``CfnMember.VotingPolicyProperty.ApprovalThresholdPolicy``.
 
             see
@@ -726,15 +665,9 @@ class CfnMemberProps:
     def __init__(
         self,
         *,
-        member_configuration: typing.Union[
-            "CfnMember.MemberConfigurationProperty", _IResolvable_9ceae33e
-        ],
+        member_configuration: typing.Union["CfnMember.MemberConfigurationProperty", _IResolvable_9ceae33e],
         invitation_id: typing.Optional[str] = None,
-        network_configuration: typing.Optional[
-            typing.Union[
-                "CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        network_configuration: typing.Optional[typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]] = None,
         network_id: typing.Optional[str] = None,
     ) -> None:
         """Properties for defining a ``AWS::ManagedBlockchain::Member``.
@@ -780,9 +713,7 @@ class CfnMemberProps:
     @builtins.property
     def network_configuration(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnMember.NetworkConfigurationProperty", _IResolvable_9ceae33e]]:
         """``AWS::ManagedBlockchain::Member.NetworkConfiguration``.
 
         see
@@ -832,9 +763,7 @@ class CfnNode(
         *,
         member_id: str,
         network_id: str,
-        node_configuration: typing.Union[
-            "NodeConfigurationProperty", _IResolvable_9ceae33e
-        ],
+        node_configuration: typing.Union["NodeConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         """Create a new ``AWS::ManagedBlockchain::Node``.
 
@@ -1032,9 +961,7 @@ class CfnNodeProps:
         *,
         member_id: str,
         network_id: str,
-        node_configuration: typing.Union[
-            "CfnNode.NodeConfigurationProperty", _IResolvable_9ceae33e
-        ],
+        node_configuration: typing.Union["CfnNode.NodeConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         """Properties for defining a ``AWS::ManagedBlockchain::Node``.
 
