@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -41,19 +41,10 @@ class CfnContainer(
         id: str,
         *,
         container_name: str,
-        access_logging_enabled: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        cors_policy: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        access_logging_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]] = None,
         lifecycle_policy: typing.Optional[str] = None,
-        metric_policy: typing.Optional[
-            typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]
-        ] = None,
+        metric_policy: typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]] = None,
         policy: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -167,12 +158,7 @@ class CfnContainer(
     @jsii.member(jsii_name="corsPolicy")
     def cors_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::MediaStore::Container.CorsPolicy``.
 
         see
@@ -183,12 +169,7 @@ class CfnContainer(
     @cors_policy.setter
     def cors_policy(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CorsRuleProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "corsPolicy", value)
 
@@ -221,9 +202,7 @@ class CfnContainer(
     @metric_policy.setter
     def metric_policy(
         self,
-        value: typing.Optional[
-            typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["MetricPolicyProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "metricPolicy", value)
 
@@ -353,17 +332,7 @@ class CfnContainer(
             self,
             *,
             container_level_metrics: str,
-            metric_policy_rules: typing.Optional[
-                typing.Union[
-                    _IResolvable_9ceae33e,
-                    typing.List[
-                        typing.Union[
-                            "CfnContainer.MetricPolicyRuleProperty",
-                            _IResolvable_9ceae33e,
-                        ]
-                    ],
-                ]
-            ] = None,
+            metric_policy_rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.MetricPolicyRuleProperty", _IResolvable_9ceae33e]]]] = None,
         ) -> None:
             """
             :param container_level_metrics: ``CfnContainer.MetricPolicyProperty.ContainerLevelMetrics``.
@@ -390,16 +359,7 @@ class CfnContainer(
         @builtins.property
         def metric_policy_rules(
             self,
-        ) -> typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnContainer.MetricPolicyRuleProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ]:
+        ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.MetricPolicyRuleProperty", _IResolvable_9ceae33e]]]]:
             """``CfnContainer.MetricPolicyProperty.MetricPolicyRules``.
 
             see
@@ -488,21 +448,10 @@ class CfnContainerProps:
         self,
         *,
         container_name: str,
-        access_logging_enabled: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
-        cors_policy: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        access_logging_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
+        cors_policy: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]] = None,
         lifecycle_policy: typing.Optional[str] = None,
-        metric_policy: typing.Optional[
-            typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]
-        ] = None,
+        metric_policy: typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]] = None,
         policy: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -558,14 +507,7 @@ class CfnContainerProps:
     @builtins.property
     def cors_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnContainer.CorsRuleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::MediaStore::Container.CorsPolicy``.
 
         see
@@ -585,9 +527,7 @@ class CfnContainerProps:
     @builtins.property
     def metric_policy(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnContainer.MetricPolicyProperty", _IResolvable_9ceae33e]]:
         """``AWS::MediaStore::Container.MetricPolicy``.
 
         see
