@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
+    CfnTag as _CfnTag_b4661f1a,
     Construct as _Construct_f50a3f53,
-    TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
-    CfnTag as _CfnTag_b4661f1a,
     TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -257,9 +257,7 @@ class CfnDevice(
         *,
         global_network_id: str,
         description: typing.Optional[str] = None,
-        location: typing.Optional[
-            typing.Union["LocationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        location: typing.Optional[typing.Union["LocationProperty", _IResolvable_9ceae33e]] = None,
         model: typing.Optional[str] = None,
         serial_number: typing.Optional[str] = None,
         site_id: typing.Optional[str] = None,
@@ -564,9 +562,7 @@ class CfnDeviceProps:
         *,
         global_network_id: str,
         description: typing.Optional[str] = None,
-        location: typing.Optional[
-            typing.Union["CfnDevice.LocationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        location: typing.Optional[typing.Union["CfnDevice.LocationProperty", _IResolvable_9ceae33e]] = None,
         model: typing.Optional[str] = None,
         serial_number: typing.Optional[str] = None,
         site_id: typing.Optional[str] = None,
@@ -630,9 +626,7 @@ class CfnDeviceProps:
     @builtins.property
     def location(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnDevice.LocationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnDevice.LocationProperty", _IResolvable_9ceae33e]]:
         """``AWS::NetworkManager::Device.Location``.
 
         see
@@ -1068,7 +1062,10 @@ class CfnLink(
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_networkmanager.CfnLink.BandwidthProperty",
         jsii_struct_bases=[],
-        name_mapping={"download_speed": "downloadSpeed", "upload_speed": "uploadSpeed"},
+        name_mapping={
+            "download_speed": "downloadSpeed",
+            "upload_speed": "uploadSpeed",
+        },
     )
     class BandwidthProperty:
         def __init__(
@@ -1446,9 +1443,7 @@ class CfnSite(
         *,
         global_network_id: str,
         description: typing.Optional[str] = None,
-        location: typing.Optional[
-            typing.Union["LocationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        location: typing.Optional[typing.Union["LocationProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::NetworkManager::Site``.
@@ -1663,9 +1658,7 @@ class CfnSiteProps:
         *,
         global_network_id: str,
         description: typing.Optional[str] = None,
-        location: typing.Optional[
-            typing.Union["CfnSite.LocationProperty", _IResolvable_9ceae33e]
-        ] = None,
+        location: typing.Optional[typing.Union["CfnSite.LocationProperty", _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::NetworkManager::Site``.
@@ -1709,9 +1702,7 @@ class CfnSiteProps:
     @builtins.property
     def location(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnSite.LocationProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnSite.LocationProperty", _IResolvable_9ceae33e]]:
         """``AWS::NetworkManager::Site.Location``.
 
         see
@@ -1770,7 +1761,8 @@ class CfnTransitGatewayRegistration(
         :param transit_gateway_arn: ``AWS::NetworkManager::TransitGatewayRegistration.TransitGatewayArn``.
         """
         props = CfnTransitGatewayRegistrationProps(
-            global_network_id=global_network_id, transit_gateway_arn=transit_gateway_arn
+            global_network_id=global_network_id,
+            transit_gateway_arn=transit_gateway_arn,
         )
 
         jsii.create(CfnTransitGatewayRegistration, self, [scope, id, props])
