@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -41,9 +41,7 @@ class CfnLedger(
         id: str,
         *,
         permissions_mode: str,
-        deletion_protection: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        deletion_protection: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         name: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -168,9 +166,7 @@ class CfnLedgerProps:
         self,
         *,
         permissions_mode: str,
-        deletion_protection: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        deletion_protection: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         name: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
@@ -264,9 +260,7 @@ class CfnStream(
         id: str,
         *,
         inclusive_start_time: str,
-        kinesis_configuration: typing.Union[
-            "KinesisConfigurationProperty", _IResolvable_9ceae33e
-        ],
+        kinesis_configuration: typing.Union["KinesisConfigurationProperty", _IResolvable_9ceae33e],
         ledger_name: str,
         role_arn: str,
         stream_name: str,
@@ -384,7 +378,8 @@ class CfnStream(
 
     @kinesis_configuration.setter
     def kinesis_configuration(
-        self, value: typing.Union["KinesisConfigurationProperty", _IResolvable_9ceae33e]
+        self,
+        value: typing.Union["KinesisConfigurationProperty", _IResolvable_9ceae33e],
     ) -> None:
         jsii.set(self, "kinesisConfiguration", value)
 
@@ -456,9 +451,7 @@ class CfnStream(
         def __init__(
             self,
             *,
-            aggregation_enabled: typing.Optional[
-                typing.Union[bool, _IResolvable_9ceae33e]
-            ] = None,
+            aggregation_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
             stream_arn: typing.Optional[str] = None,
         ) -> None:
             """
@@ -524,9 +517,7 @@ class CfnStreamProps:
         self,
         *,
         inclusive_start_time: str,
-        kinesis_configuration: typing.Union[
-            "CfnStream.KinesisConfigurationProperty", _IResolvable_9ceae33e
-        ],
+        kinesis_configuration: typing.Union["CfnStream.KinesisConfigurationProperty", _IResolvable_9ceae33e],
         ledger_name: str,
         role_arn: str,
         stream_name: str,
