@@ -41,10 +41,10 @@ class HttpsRedirect(
         """
         :param scope: -
         :param id: -
-        :param target_domain: The redirect target domain.
-        :param zone: HostedZone of the domain.
-        :param certificate: The ACM certificate; Has to be in us-east-1 Default: - create a new certificate in us-east-1
-        :param record_names: The domain names to create that will redirect to ``targetDomain``. Default: - the domain name of the zone
+        :param target_domain: The redirect target fully qualified domain name (FQDN). An alias record will be created that points to your CloudFront distribution. Root domain or sub-domain can be supplied.
+        :param zone: Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain. The hosted zone must contain entries for the domain name(s) supplied through ``recordNames`` that will redirect to the target domain. Domain names in the hosted zone can include a specific domain (example.com) and its subdomains (acme.example.com, zenith.example.com).
+        :param certificate: The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. If provided, the certificate must be stored in us-east-1 (N. Virginia) Default: - A new certificate is created in us-east-1 (N. Virginia)
+        :param record_names: The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
 
         stability
         :stability: experimental
@@ -80,10 +80,10 @@ class HttpsRedirectProps:
     ) -> None:
         """Properties to configure an HTTPS Redirect.
 
-        :param target_domain: The redirect target domain.
-        :param zone: HostedZone of the domain.
-        :param certificate: The ACM certificate; Has to be in us-east-1 Default: - create a new certificate in us-east-1
-        :param record_names: The domain names to create that will redirect to ``targetDomain``. Default: - the domain name of the zone
+        :param target_domain: The redirect target fully qualified domain name (FQDN). An alias record will be created that points to your CloudFront distribution. Root domain or sub-domain can be supplied.
+        :param zone: Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain. The hosted zone must contain entries for the domain name(s) supplied through ``recordNames`` that will redirect to the target domain. Domain names in the hosted zone can include a specific domain (example.com) and its subdomains (acme.example.com, zenith.example.com).
+        :param certificate: The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created. If provided, the certificate must be stored in us-east-1 (N. Virginia) Default: - A new certificate is created in us-east-1 (N. Virginia)
+        :param record_names: The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
 
         stability
         :stability: experimental
@@ -99,7 +99,11 @@ class HttpsRedirectProps:
 
     @builtins.property
     def target_domain(self) -> str:
-        """The redirect target domain.
+        """The redirect target fully qualified domain name (FQDN).
+
+        An alias record
+        will be created that points to your CloudFront distribution. Root domain
+        or sub-domain can be supplied.
 
         stability
         :stability: experimental
@@ -108,7 +112,14 @@ class HttpsRedirectProps:
 
     @builtins.property
     def zone(self) -> _IHostedZone_59ffab76:
-        """HostedZone of the domain.
+        """Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain.
+
+        The hosted zone must
+        contain entries for the domain name(s) supplied through ``recordNames`` that
+        will redirect to the target domain.
+
+        Domain names in the hosted zone can include a specific domain (example.com)
+        and its subdomains (acme.example.com, zenith.example.com).
 
         stability
         :stability: experimental
@@ -117,12 +128,13 @@ class HttpsRedirectProps:
 
     @builtins.property
     def certificate(self) -> typing.Optional[_ICertificate_8f3d4c96]:
-        """The ACM certificate;
+        """The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created.
 
-        Has to be in us-east-1
+        If provided, the certificate must be
+        stored in us-east-1 (N. Virginia)
 
         default
-        :default: - create a new certificate in us-east-1
+        :default: - A new certificate is created in us-east-1 (N. Virginia)
 
         stability
         :stability: experimental
@@ -131,10 +143,10 @@ class HttpsRedirectProps:
 
     @builtins.property
     def record_names(self) -> typing.Optional[typing.List[str]]:
-        """The domain names to create that will redirect to ``targetDomain``.
+        """The domain names that will redirect to ``targetDomain``.
 
         default
-        :default: - the domain name of the zone
+        :default: - the domain name of the hosted zone
 
         stability
         :stability: experimental
