@@ -15,6 +15,7 @@ from .. import (
     BundlingOptions as _BundlingOptions_0cab5223,
     Construct as _Construct_f50a3f53,
     Duration as _Duration_5170c158,
+    Expiration as _Expiration_a422b4f1,
 )
 from ..assets import FollowMode as _FollowMode_f74e7125
 from ..aws_cloudfront import IDistribution as _IDistribution_0af1f2d0
@@ -48,7 +49,7 @@ class BucketDeployment(
         destination_key_prefix: typing.Optional[str] = None,
         distribution: typing.Optional[_IDistribution_0af1f2d0] = None,
         distribution_paths: typing.Optional[typing.List[str]] = None,
-        expires: typing.Optional["Expires"] = None,
+        expires: typing.Optional[_Expiration_a422b4f1] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         metadata: typing.Optional["UserDefinedObjectMetadata"] = None,
         prune: typing.Optional[bool] = None,
@@ -156,7 +157,7 @@ class BucketDeploymentProps:
         destination_key_prefix: typing.Optional[str] = None,
         distribution: typing.Optional[_IDistribution_0af1f2d0] = None,
         distribution_paths: typing.Optional[typing.List[str]] = None,
-        expires: typing.Optional["Expires"] = None,
+        expires: typing.Optional[_Expiration_a422b4f1] = None,
         memory_limit: typing.Optional[jsii.Number] = None,
         metadata: typing.Optional["UserDefinedObjectMetadata"] = None,
         prune: typing.Optional[bool] = None,
@@ -367,7 +368,7 @@ class BucketDeploymentProps:
         return self._values.get("distribution_paths")
 
     @builtins.property
-    def expires(self) -> typing.Optional["Expires"]:
+    def expires(self) -> typing.Optional[_Expiration_a422b4f1]:
         """System-defined expires metadata to be set on all objects in the deployment.
 
         default
@@ -691,10 +692,13 @@ class Expires(
 
     Does NOT influence deletion of the object.
 
+    deprecated
+    :deprecated: use core.Expiration
+
     see
     :see: https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingMetadata.html#SysMetadata
     stability
-    :stability: experimental
+    :stability: deprecated
     """
 
     @jsii.member(jsii_name="after")
@@ -705,7 +709,7 @@ class Expires(
         :param t: the duration to wait before expiring.
 
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return jsii.sinvoke(cls, "after", [t])
 
@@ -717,7 +721,7 @@ class Expires(
         :param d: date to expire at.
 
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return jsii.sinvoke(cls, "atDate", [d])
 
@@ -729,7 +733,7 @@ class Expires(
         :param t: timestamp in unix milliseconds.
 
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return jsii.sinvoke(cls, "atTimestamp", [t])
 
@@ -740,7 +744,7 @@ class Expires(
         :param s: -
 
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return jsii.sinvoke(cls, "fromString", [s])
 
@@ -749,7 +753,7 @@ class Expires(
     def value(self) -> typing.Any:
         """
         stability
-        :stability: experimental
+        :stability: deprecated
         """
         return jsii.get(self, "value")
 
