@@ -13,9 +13,9 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
+    IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
     TreeInspector as _TreeInspector_154f5999,
-    IInspectable as _IInspectable_051e6ed8,
 )
 
 
@@ -39,14 +39,7 @@ class CfnByteMatchSet(
         id: str,
         *,
         name: str,
-        byte_match_tuples: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["ByteMatchTupleProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        byte_match_tuples: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ByteMatchTupleProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::ByteMatchSet``.
 
@@ -108,12 +101,7 @@ class CfnByteMatchSet(
     @jsii.member(jsii_name="byteMatchTuples")
     def byte_match_tuples(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ByteMatchTupleProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ByteMatchTupleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::ByteMatchSet.ByteMatchTuples``.
 
         see
@@ -124,14 +112,7 @@ class CfnByteMatchSet(
     @byte_match_tuples.setter
     def byte_match_tuples(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["ByteMatchTupleProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ByteMatchTupleProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "byteMatchTuples", value)
 
@@ -150,9 +131,7 @@ class CfnByteMatchSet(
         def __init__(
             self,
             *,
-            field_to_match: typing.Union[
-                "CfnByteMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e
-            ],
+            field_to_match: typing.Union["CfnByteMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e],
             positional_constraint: str,
             text_transformation: str,
             target_string: typing.Optional[str] = None,
@@ -181,9 +160,7 @@ class CfnByteMatchSet(
         @builtins.property
         def field_to_match(
             self,
-        ) -> typing.Union[
-            "CfnByteMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e
-        ]:
+        ) -> typing.Union["CfnByteMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e]:
             """``CfnByteMatchSet.ByteMatchTupleProperty.FieldToMatch``.
 
             see
@@ -298,16 +275,7 @@ class CfnByteMatchSetProps:
         self,
         *,
         name: str,
-        byte_match_tuples: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnByteMatchSet.ByteMatchTupleProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        byte_match_tuples: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnByteMatchSet.ByteMatchTupleProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::ByteMatchSet``.
 
@@ -335,16 +303,7 @@ class CfnByteMatchSetProps:
     @builtins.property
     def byte_match_tuples(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnByteMatchSet.ByteMatchTupleProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnByteMatchSet.ByteMatchTupleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::ByteMatchSet.ByteMatchTuples``.
 
         see
@@ -384,14 +343,7 @@ class CfnIPSet(
         id: str,
         *,
         name: str,
-        ip_set_descriptors: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["IPSetDescriptorProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        ip_set_descriptors: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["IPSetDescriptorProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::IPSet``.
 
@@ -453,12 +405,7 @@ class CfnIPSet(
     @jsii.member(jsii_name="ipSetDescriptors")
     def ip_set_descriptors(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["IPSetDescriptorProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["IPSetDescriptorProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::IPSet.IPSetDescriptors``.
 
         see
@@ -469,14 +416,7 @@ class CfnIPSet(
     @ip_set_descriptors.setter
     def ip_set_descriptors(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["IPSetDescriptorProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["IPSetDescriptorProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "ipSetDescriptors", value)
 
@@ -513,6 +453,7 @@ class CfnIPSet(
             """
             ...
 
+
     class _IPSetDescriptorPropertyProxy:
         """
         see
@@ -552,16 +493,7 @@ class CfnIPSetProps:
         self,
         *,
         name: str,
-        ip_set_descriptors: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnIPSet.IPSetDescriptorProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        ip_set_descriptors: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnIPSet.IPSetDescriptorProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::IPSet``.
 
@@ -589,14 +521,7 @@ class CfnIPSetProps:
     @builtins.property
     def ip_set_descriptors(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnIPSet.IPSetDescriptorProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnIPSet.IPSetDescriptorProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::IPSet.IPSetDescriptors``.
 
         see
@@ -637,12 +562,7 @@ class CfnRule(
         *,
         metric_name: str,
         name: str,
-        predicates: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["PredicateProperty", _IResolvable_9ceae33e]],
-            ]
-        ] = None,
+        predicates: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PredicateProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::Rule``.
 
@@ -719,12 +639,7 @@ class CfnRule(
     @jsii.member(jsii_name="predicates")
     def predicates(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["PredicateProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PredicateProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::Rule.Predicates``.
 
         see
@@ -735,12 +650,7 @@ class CfnRule(
     @predicates.setter
     def predicates(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[typing.Union["PredicateProperty", _IResolvable_9ceae33e]],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["PredicateProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "predicates", value)
 
@@ -825,14 +735,7 @@ class CfnRuleProps:
         *,
         metric_name: str,
         name: str,
-        predicates: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["CfnRule.PredicateProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        predicates: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnRule.PredicateProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::Rule``.
 
@@ -871,14 +774,7 @@ class CfnRuleProps:
     @builtins.property
     def predicates(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnRule.PredicateProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnRule.PredicateProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::Rule.Predicates``.
 
         see
@@ -918,10 +814,7 @@ class CfnSizeConstraintSet(
         id: str,
         *,
         name: str,
-        size_constraints: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["SizeConstraintProperty", _IResolvable_9ceae33e]],
-        ],
+        size_constraints: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SizeConstraintProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         """Create a new ``AWS::WAF::SizeConstraintSet``.
 
@@ -983,10 +876,7 @@ class CfnSizeConstraintSet(
     @jsii.member(jsii_name="sizeConstraints")
     def size_constraints(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["SizeConstraintProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SizeConstraintProperty", _IResolvable_9ceae33e]]]:
         """``AWS::WAF::SizeConstraintSet.SizeConstraints``.
 
         see
@@ -997,10 +887,7 @@ class CfnSizeConstraintSet(
     @size_constraints.setter
     def size_constraints(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["SizeConstraintProperty", _IResolvable_9ceae33e]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SizeConstraintProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "sizeConstraints", value)
 
@@ -1068,9 +955,7 @@ class CfnSizeConstraintSet(
             self,
             *,
             comparison_operator: str,
-            field_to_match: typing.Union[
-                "CfnSizeConstraintSet.FieldToMatchProperty", _IResolvable_9ceae33e
-            ],
+            field_to_match: typing.Union["CfnSizeConstraintSet.FieldToMatchProperty", _IResolvable_9ceae33e],
             size: jsii.Number,
             text_transformation: str,
         ) -> None:
@@ -1102,9 +987,7 @@ class CfnSizeConstraintSet(
         @builtins.property
         def field_to_match(
             self,
-        ) -> typing.Union[
-            "CfnSizeConstraintSet.FieldToMatchProperty", _IResolvable_9ceae33e
-        ]:
+        ) -> typing.Union["CfnSizeConstraintSet.FieldToMatchProperty", _IResolvable_9ceae33e]:
             """``CfnSizeConstraintSet.SizeConstraintProperty.FieldToMatch``.
 
             see
@@ -1152,14 +1035,7 @@ class CfnSizeConstraintSetProps:
         self,
         *,
         name: str,
-        size_constraints: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnSizeConstraintSet.SizeConstraintProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ],
+        size_constraints: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnSizeConstraintSet.SizeConstraintProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         """Properties for defining a ``AWS::WAF::SizeConstraintSet``.
 
@@ -1186,14 +1062,7 @@ class CfnSizeConstraintSetProps:
     @builtins.property
     def size_constraints(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[
-            typing.Union[
-                "CfnSizeConstraintSet.SizeConstraintProperty", _IResolvable_9ceae33e
-            ]
-        ],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnSizeConstraintSet.SizeConstraintProperty", _IResolvable_9ceae33e]]]:
         """``AWS::WAF::SizeConstraintSet.SizeConstraints``.
 
         see
@@ -1233,16 +1102,7 @@ class CfnSqlInjectionMatchSet(
         id: str,
         *,
         name: str,
-        sql_injection_match_tuples: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "SqlInjectionMatchTupleProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        sql_injection_match_tuples: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SqlInjectionMatchTupleProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::SqlInjectionMatchSet``.
 
@@ -1306,14 +1166,7 @@ class CfnSqlInjectionMatchSet(
     @jsii.member(jsii_name="sqlInjectionMatchTuples")
     def sql_injection_match_tuples(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["SqlInjectionMatchTupleProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SqlInjectionMatchTupleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::SqlInjectionMatchSet.SqlInjectionMatchTuples``.
 
         see
@@ -1324,16 +1177,7 @@ class CfnSqlInjectionMatchSet(
     @sql_injection_match_tuples.setter
     def sql_injection_match_tuples(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "SqlInjectionMatchTupleProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["SqlInjectionMatchTupleProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "sqlInjectionMatchTuples", value)
 
@@ -1398,9 +1242,7 @@ class CfnSqlInjectionMatchSet(
         def __init__(
             self,
             *,
-            field_to_match: typing.Union[
-                "CfnSqlInjectionMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e
-            ],
+            field_to_match: typing.Union["CfnSqlInjectionMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e],
             text_transformation: str,
         ) -> None:
             """
@@ -1418,9 +1260,7 @@ class CfnSqlInjectionMatchSet(
         @builtins.property
         def field_to_match(
             self,
-        ) -> typing.Union[
-            "CfnSqlInjectionMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e
-        ]:
+        ) -> typing.Union["CfnSqlInjectionMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e]:
             """``CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty.FieldToMatch``.
 
             see
@@ -1462,17 +1302,7 @@ class CfnSqlInjectionMatchSetProps:
         self,
         *,
         name: str,
-        sql_injection_match_tuples: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty",
-                        _IResolvable_9ceae33e,
-                    ]
-                ],
-            ]
-        ] = None,
+        sql_injection_match_tuples: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::SqlInjectionMatchSet``.
 
@@ -1500,17 +1330,7 @@ class CfnSqlInjectionMatchSetProps:
     @builtins.property
     def sql_injection_match_tuples(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty",
-                    _IResolvable_9ceae33e,
-                ]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnSqlInjectionMatchSet.SqlInjectionMatchTupleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::SqlInjectionMatchSet.SqlInjectionMatchTuples``.
 
         see
@@ -1552,14 +1372,7 @@ class CfnWebACL(
         default_action: typing.Union["WafActionProperty", _IResolvable_9ceae33e],
         metric_name: str,
         name: str,
-        rules: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["ActivatedRuleProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ] = None,
+        rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ActivatedRuleProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Create a new ``AWS::WAF::WebACL``.
 
@@ -1660,12 +1473,7 @@ class CfnWebACL(
     @jsii.member(jsii_name="rules")
     def rules(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["ActivatedRuleProperty", _IResolvable_9ceae33e]],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ActivatedRuleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::WebACL.Rules``.
 
         see
@@ -1676,14 +1484,7 @@ class CfnWebACL(
     @rules.setter
     def rules(
         self,
-        value: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union["ActivatedRuleProperty", _IResolvable_9ceae33e]
-                ],
-            ]
-        ],
+        value: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["ActivatedRuleProperty", _IResolvable_9ceae33e]]]],
     ) -> None:
         jsii.set(self, "rules", value)
 
@@ -1698,9 +1499,7 @@ class CfnWebACL(
             *,
             priority: jsii.Number,
             rule_id: str,
-            action: typing.Optional[
-                typing.Union["CfnWebACL.WafActionProperty", _IResolvable_9ceae33e]
-            ] = None,
+            action: typing.Optional[typing.Union["CfnWebACL.WafActionProperty", _IResolvable_9ceae33e]] = None,
         ) -> None:
             """
             :param priority: ``CfnWebACL.ActivatedRuleProperty.Priority``.
@@ -1738,9 +1537,7 @@ class CfnWebACL(
         @builtins.property
         def action(
             self,
-        ) -> typing.Optional[
-            typing.Union["CfnWebACL.WafActionProperty", _IResolvable_9ceae33e]
-        ]:
+        ) -> typing.Optional[typing.Union["CfnWebACL.WafActionProperty", _IResolvable_9ceae33e]]:
             """``CfnWebACL.ActivatedRuleProperty.Action``.
 
             see
@@ -1811,21 +1608,10 @@ class CfnWebACLProps:
     def __init__(
         self,
         *,
-        default_action: typing.Union[
-            "CfnWebACL.WafActionProperty", _IResolvable_9ceae33e
-        ],
+        default_action: typing.Union["CfnWebACL.WafActionProperty", _IResolvable_9ceae33e],
         metric_name: str,
         name: str,
-        rules: typing.Optional[
-            typing.Union[
-                _IResolvable_9ceae33e,
-                typing.List[
-                    typing.Union[
-                        "CfnWebACL.ActivatedRuleProperty", _IResolvable_9ceae33e
-                    ]
-                ],
-            ]
-        ] = None,
+        rules: typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnWebACL.ActivatedRuleProperty", _IResolvable_9ceae33e]]]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WAF::WebACL``.
 
@@ -1877,14 +1663,7 @@ class CfnWebACLProps:
     @builtins.property
     def rules(
         self,
-    ) -> typing.Optional[
-        typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union["CfnWebACL.ActivatedRuleProperty", _IResolvable_9ceae33e]
-            ],
-        ]
-    ]:
+    ) -> typing.Optional[typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnWebACL.ActivatedRuleProperty", _IResolvable_9ceae33e]]]]:
         """``AWS::WAF::WebACL.Rules``.
 
         see
@@ -1924,10 +1703,7 @@ class CfnXssMatchSet(
         id: str,
         *,
         name: str,
-        xss_match_tuples: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["XssMatchTupleProperty", _IResolvable_9ceae33e]],
-        ],
+        xss_match_tuples: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["XssMatchTupleProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         """Create a new ``AWS::WAF::XssMatchSet``.
 
@@ -1989,10 +1765,7 @@ class CfnXssMatchSet(
     @jsii.member(jsii_name="xssMatchTuples")
     def xss_match_tuples(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[typing.Union["XssMatchTupleProperty", _IResolvable_9ceae33e]],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["XssMatchTupleProperty", _IResolvable_9ceae33e]]]:
         """``AWS::WAF::XssMatchSet.XssMatchTuples``.
 
         see
@@ -2003,10 +1776,7 @@ class CfnXssMatchSet(
     @xss_match_tuples.setter
     def xss_match_tuples(
         self,
-        value: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[typing.Union["XssMatchTupleProperty", _IResolvable_9ceae33e]],
-        ],
+        value: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["XssMatchTupleProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         jsii.set(self, "xssMatchTuples", value)
 
@@ -2071,9 +1841,7 @@ class CfnXssMatchSet(
         def __init__(
             self,
             *,
-            field_to_match: typing.Union[
-                "CfnXssMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e
-            ],
+            field_to_match: typing.Union["CfnXssMatchSet.FieldToMatchProperty", _IResolvable_9ceae33e],
             text_transformation: str,
         ) -> None:
             """
@@ -2130,14 +1898,7 @@ class CfnXssMatchSetProps:
         self,
         *,
         name: str,
-        xss_match_tuples: typing.Union[
-            _IResolvable_9ceae33e,
-            typing.List[
-                typing.Union[
-                    "CfnXssMatchSet.XssMatchTupleProperty", _IResolvable_9ceae33e
-                ]
-            ],
-        ],
+        xss_match_tuples: typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnXssMatchSet.XssMatchTupleProperty", _IResolvable_9ceae33e]]],
     ) -> None:
         """Properties for defining a ``AWS::WAF::XssMatchSet``.
 
@@ -2164,12 +1925,7 @@ class CfnXssMatchSetProps:
     @builtins.property
     def xss_match_tuples(
         self,
-    ) -> typing.Union[
-        _IResolvable_9ceae33e,
-        typing.List[
-            typing.Union["CfnXssMatchSet.XssMatchTupleProperty", _IResolvable_9ceae33e]
-        ],
-    ]:
+    ) -> typing.Union[_IResolvable_9ceae33e, typing.List[typing.Union["CfnXssMatchSet.XssMatchTupleProperty", _IResolvable_9ceae33e]]]:
         """``AWS::WAF::XssMatchSet.XssMatchTuples``.
 
         see
