@@ -12,12 +12,12 @@ from .._jsii import *
 
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
-    Construct as _Construct_f50a3f53,
-    IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    TreeInspector as _TreeInspector_154f5999,
-    TagManager as _TagManager_2508893f,
+    Construct as _Construct_f50a3f53,
     IInspectable as _IInspectable_051e6ed8,
+    IResolvable as _IResolvable_9ceae33e,
+    TagManager as _TagManager_2508893f,
+    TreeInspector as _TreeInspector_154f5999,
 )
 
 
@@ -43,17 +43,11 @@ class CfnWorkspace(
         bundle_id: str,
         directory_id: str,
         user_name: str,
-        root_volume_encryption_enabled: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        root_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        user_volume_encryption_enabled: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        user_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         volume_encryption_key: typing.Optional[str] = None,
-        workspace_properties: typing.Optional[
-            typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]
-        ] = None,
+        workspace_properties: typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Create a new ``AWS::WorkSpaces::Workspace``.
 
@@ -218,9 +212,7 @@ class CfnWorkspace(
     @jsii.member(jsii_name="workspaceProperties")
     def workspace_properties(
         self,
-    ) -> typing.Optional[
-        typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
         see
@@ -231,9 +223,7 @@ class CfnWorkspace(
     @workspace_properties.setter
     def workspace_properties(
         self,
-        value: typing.Optional[
-            typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]
-        ],
+        value: typing.Optional[typing.Union["WorkspacePropertiesProperty", _IResolvable_9ceae33e]],
     ) -> None:
         jsii.set(self, "workspaceProperties", value)
 
@@ -255,9 +245,7 @@ class CfnWorkspace(
             compute_type_name: typing.Optional[str] = None,
             root_volume_size_gib: typing.Optional[jsii.Number] = None,
             running_mode: typing.Optional[str] = None,
-            running_mode_auto_stop_timeout_in_minutes: typing.Optional[
-                jsii.Number
-            ] = None,
+            running_mode_auto_stop_timeout_in_minutes: typing.Optional[jsii.Number] = None,
             user_volume_size_gib: typing.Optional[jsii.Number] = None,
         ) -> None:
             """
@@ -278,9 +266,7 @@ class CfnWorkspace(
             if running_mode is not None:
                 self._values["running_mode"] = running_mode
             if running_mode_auto_stop_timeout_in_minutes is not None:
-                self._values[
-                    "running_mode_auto_stop_timeout_in_minutes"
-                ] = running_mode_auto_stop_timeout_in_minutes
+                self._values["running_mode_auto_stop_timeout_in_minutes"] = running_mode_auto_stop_timeout_in_minutes
             if user_volume_size_gib is not None:
                 self._values["user_volume_size_gib"] = user_volume_size_gib
 
@@ -364,19 +350,11 @@ class CfnWorkspaceProps:
         bundle_id: str,
         directory_id: str,
         user_name: str,
-        root_volume_encryption_enabled: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        root_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
-        user_volume_encryption_enabled: typing.Optional[
-            typing.Union[bool, _IResolvable_9ceae33e]
-        ] = None,
+        user_volume_encryption_enabled: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         volume_encryption_key: typing.Optional[str] = None,
-        workspace_properties: typing.Optional[
-            typing.Union[
-                "CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e
-            ]
-        ] = None,
+        workspace_properties: typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]] = None,
     ) -> None:
         """Properties for defining a ``AWS::WorkSpaces::Workspace``.
 
@@ -398,15 +376,11 @@ class CfnWorkspaceProps:
             "user_name": user_name,
         }
         if root_volume_encryption_enabled is not None:
-            self._values[
-                "root_volume_encryption_enabled"
-            ] = root_volume_encryption_enabled
+            self._values["root_volume_encryption_enabled"] = root_volume_encryption_enabled
         if tags is not None:
             self._values["tags"] = tags
         if user_volume_encryption_enabled is not None:
-            self._values[
-                "user_volume_encryption_enabled"
-            ] = user_volume_encryption_enabled
+            self._values["user_volume_encryption_enabled"] = user_volume_encryption_enabled
         if volume_encryption_key is not None:
             self._values["volume_encryption_key"] = volume_encryption_key
         if workspace_properties is not None:
@@ -482,9 +456,7 @@ class CfnWorkspaceProps:
     @builtins.property
     def workspace_properties(
         self,
-    ) -> typing.Optional[
-        typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]
-    ]:
+    ) -> typing.Optional[typing.Union["CfnWorkspace.WorkspacePropertiesProperty", _IResolvable_9ceae33e]]:
         """``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
         see
