@@ -465,6 +465,16 @@ class CloudAssembly(
         """
         return jsii.get(self, "manifest")
 
+    @builtins.property
+    @jsii.member(jsii_name="nestedAssemblies")
+    def nested_assemblies(self) -> typing.List["NestedCloudAssemblyArtifact"]:
+        """The nested assembly artifacts in this assembly.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "nestedAssemblies")
+
     @builtins.property
     @jsii.member(jsii_name="runtime")
     def runtime(self) -> _RuntimeInfo_847d082a:
@@ -753,6 +763,16 @@ class CloudFormationStackArtifact(
         """
         return jsii.get(self, "templateFile")
 
+    @builtins.property
+    @jsii.member(jsii_name="templateFullPath")
+    def template_full_path(self) -> str:
+        """Full path to the template file.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "templateFullPath")
+
     @builtins.property
     @jsii.member(jsii_name="assumeRoleArn")
     def assume_role_arn(self) -> typing.Optional[str]:
